# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.

from typing import List, Optional

from scaleway_core.api import API
from scaleway_core.utils import (
    WaitForOptions,
    validate_path_param,
    fetch_all_pages,
    wait_for_resource,
)
from .types import (
    ListBackendStagesRequestOrderBy,
    ListCacheStagesRequestOrderBy,
    ListDNSStagesRequestOrderBy,
    ListPipelinesRequestOrderBy,
    ListPurgeRequestsRequestOrderBy,
    ListTLSStagesRequestOrderBy,
    BackendStage,
    CacheStage,
    CheckDomainRequest,
    CheckDomainResponse,
    CheckLbOriginRequest,
    CheckLbOriginResponse,
    CheckPEMChainRequest,
    CheckPEMChainRequestSecretChain,
    CheckPEMChainResponse,
    CreateBackendStageRequest,
    CreateCacheStageRequest,
    CreateDNSStageRequest,
    CreatePipelineRequest,
    CreatePurgeRequestRequest,
    CreateTLSStageRequest,
    DNSStage,
    ListBackendStagesResponse,
    ListCacheStagesResponse,
    ListDNSStagesResponse,
    ListPipelinesResponse,
    ListPurgeRequestsResponse,
    ListTLSStagesResponse,
    Pipeline,
    PurgeRequest,
    ScalewayLb,
    ScalewayLbBackendConfig,
    ScalewayS3BackendConfig,
    TLSSecret,
    TLSSecretsConfig,
    TLSStage,
    UpdateBackendStageRequest,
    UpdateCacheStageRequest,
    UpdateDNSStageRequest,
    UpdatePipelineRequest,
    UpdateTLSStageRequest,
)
from .content import (
    PIPELINE_TRANSIENT_STATUSES,
    PURGE_REQUEST_TRANSIENT_STATUSES,
)
from .marshalling import (
    unmarshal_BackendStage,
    unmarshal_CacheStage,
    unmarshal_DNSStage,
    unmarshal_Pipeline,
    unmarshal_PurgeRequest,
    unmarshal_TLSStage,
    unmarshal_CheckDomainResponse,
    unmarshal_CheckLbOriginResponse,
    unmarshal_CheckPEMChainResponse,
    unmarshal_ListBackendStagesResponse,
    unmarshal_ListCacheStagesResponse,
    unmarshal_ListDNSStagesResponse,
    unmarshal_ListPipelinesResponse,
    unmarshal_ListPurgeRequestsResponse,
    unmarshal_ListTLSStagesResponse,
    marshal_CheckDomainRequest,
    marshal_CheckLbOriginRequest,
    marshal_CheckPEMChainRequest,
    marshal_CreateBackendStageRequest,
    marshal_CreateCacheStageRequest,
    marshal_CreateDNSStageRequest,
    marshal_CreatePipelineRequest,
    marshal_CreatePurgeRequestRequest,
    marshal_CreateTLSStageRequest,
    marshal_UpdateBackendStageRequest,
    marshal_UpdateCacheStageRequest,
    marshal_UpdateDNSStageRequest,
    marshal_UpdatePipelineRequest,
    marshal_UpdateTLSStageRequest,
)


class EdgeServicesV1Alpha1API(API):
    """ """

    def list_pipelines(
        self,
        *,
        order_by: Optional[ListPipelinesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        name: Optional[str] = None,
        organization_id: Optional[str] = None,
        project_id: Optional[str] = None,
        has_backend_stage_lb: Optional[bool] = None,
    ) -> ListPipelinesResponse:
        """
        List pipelines.
        List all pipelines, for a Scaleway Organization or Scaleway Project. By default, the pipelines returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param order_by: Sort order of pipelines in the response.
        :param page: Page number to return, from the paginated results.
        :param page_size: Number of pipelines to return per page.
        :param name: Pipeline name to filter for, only pipelines with this string within their name will be returned.
        :param organization_id: Organization ID to filter for, only pipelines from this Organization will be returned.
        :param project_id: Project ID to filter for, only pipelines from this Project will be returned.
        :param has_backend_stage_lb: Filter on backend stage, only pipelines with a Load Balancer origin will be returned.
        :return: :class:`ListPipelinesResponse <ListPipelinesResponse>`

        Usage:
        ::

            result = api.list_pipelines()
        """

        res = self._request(
            "GET",
            "/edge-services/v1alpha1/pipelines",
            params={
                "has_backend_stage_lb": has_backend_stage_lb,
                "name": name,
                "order_by": order_by,
                "organization_id": organization_id
                or self.client.default_organization_id,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListPipelinesResponse(res.json())

    def list_pipelines_all(
        self,
        *,
        order_by: Optional[ListPipelinesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        name: Optional[str] = None,
        organization_id: Optional[str] = None,
        project_id: Optional[str] = None,
        has_backend_stage_lb: Optional[bool] = None,
    ) -> List[Pipeline]:
        """
        List pipelines.
        List all pipelines, for a Scaleway Organization or Scaleway Project. By default, the pipelines returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param order_by: Sort order of pipelines in the response.
        :param page: Page number to return, from the paginated results.
        :param page_size: Number of pipelines to return per page.
        :param name: Pipeline name to filter for, only pipelines with this string within their name will be returned.
        :param organization_id: Organization ID to filter for, only pipelines from this Organization will be returned.
        :param project_id: Project ID to filter for, only pipelines from this Project will be returned.
        :param has_backend_stage_lb: Filter on backend stage, only pipelines with a Load Balancer origin will be returned.
        :return: :class:`List[Pipeline] <List[Pipeline]>`

        Usage:
        ::

            result = api.list_pipelines_all()
        """

        return fetch_all_pages(
            type=ListPipelinesResponse,
            key="pipelines",
            fetcher=self.list_pipelines,
            args={
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "name": name,
                "organization_id": organization_id,
                "project_id": project_id,
                "has_backend_stage_lb": has_backend_stage_lb,
            },
        )

    def create_pipeline(
        self,
        *,
        name: str,
        description: str,
        project_id: Optional[str] = None,
        dns_stage_id: Optional[str] = None,
    ) -> Pipeline:
        """
        Create pipeline.
        Create a new pipeline. You must specify a `dns_stage_id` to form a stage-chain that goes all the way to the backend stage (origin), so the HTTP request will be processed according to the stages you created.
        :param name: Name of the pipeline.
        :param description: Description of the pipeline.
        :param project_id: Project ID in which the pipeline will be created.
        :param dns_stage_id: DNS stage ID the pipeline will be attached to.
        One-Of ('head'): at most one of 'dns_stage_id' could be set.
        :return: :class:`Pipeline <Pipeline>`

        Usage:
        ::

            result = api.create_pipeline(
                name="example",
                description="example",
            )
        """

        res = self._request(
            "POST",
            "/edge-services/v1alpha1/pipelines",
            body=marshal_CreatePipelineRequest(
                CreatePipelineRequest(
                    name=name,
                    description=description,
                    project_id=project_id,
                    dns_stage_id=dns_stage_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Pipeline(res.json())

    def get_pipeline(
        self,
        *,
        pipeline_id: str,
    ) -> Pipeline:
        """
        Get pipeline.
        Retrieve information about an existing pipeline, specified by its `pipeline_id`. Its full details, including errors, are returned in the response object.
        :param pipeline_id: ID of the requested pipeline.
        :return: :class:`Pipeline <Pipeline>`

        Usage:
        ::

            result = api.get_pipeline(
                pipeline_id="example",
            )
        """

        param_pipeline_id = validate_path_param("pipeline_id", pipeline_id)

        res = self._request(
            "GET",
            f"/edge-services/v1alpha1/pipelines/{param_pipeline_id}",
        )

        self._throw_on_error(res)
        return unmarshal_Pipeline(res.json())

    def wait_for_pipeline(
        self,
        *,
        pipeline_id: str,
        options: Optional[WaitForOptions[Pipeline, bool]] = None,
    ) -> Pipeline:
        """
        Get pipeline.
        Retrieve information about an existing pipeline, specified by its `pipeline_id`. Its full details, including errors, are returned in the response object.
        :param pipeline_id: ID of the requested pipeline.
        :return: :class:`Pipeline <Pipeline>`

        Usage:
        ::

            result = api.get_pipeline(
                pipeline_id="example",
            )
        """

        if not options:
            options = WaitForOptions()

        if not options.stop:
            options.stop = lambda res: res.status not in PIPELINE_TRANSIENT_STATUSES

        return wait_for_resource(
            fetcher=self.get_pipeline,
            options=options,
            args={
                "pipeline_id": pipeline_id,
            },
        )

    def update_pipeline(
        self,
        *,
        pipeline_id: str,
        name: Optional[str] = None,
        description: Optional[str] = None,
        dns_stage_id: Optional[str] = None,
    ) -> Pipeline:
        """
        Update pipeline.
        Update the parameters of an existing pipeline, specified by its `pipeline_id`. Parameters which can be updated include the `name`, `description` and `dns_stage_id`.
        :param pipeline_id: ID of the pipeline to update.
        :param name: Name of the pipeline.
        :param description: Description of the pipeline.
        :param dns_stage_id: DNS stage ID the pipeline will be attached to.
        One-Of ('head'): at most one of 'dns_stage_id' could be set.
        :return: :class:`Pipeline <Pipeline>`

        Usage:
        ::

            result = api.update_pipeline(
                pipeline_id="example",
            )
        """

        param_pipeline_id = validate_path_param("pipeline_id", pipeline_id)

        res = self._request(
            "PATCH",
            f"/edge-services/v1alpha1/pipelines/{param_pipeline_id}",
            body=marshal_UpdatePipelineRequest(
                UpdatePipelineRequest(
                    pipeline_id=pipeline_id,
                    name=name,
                    description=description,
                    dns_stage_id=dns_stage_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Pipeline(res.json())

    def delete_pipeline(
        self,
        *,
        pipeline_id: str,
    ) -> None:
        """
        Delete pipeline.
        Delete an existing pipeline, specified by its `pipeline_id`. Deleting a pipeline is permanent, and cannot be undone. Note that all stages linked to the pipeline are also deleted.
        :param pipeline_id: ID of the pipeline to delete.

        Usage:
        ::

            result = api.delete_pipeline(
                pipeline_id="example",
            )
        """

        param_pipeline_id = validate_path_param("pipeline_id", pipeline_id)

        res = self._request(
            "DELETE",
            f"/edge-services/v1alpha1/pipelines/{param_pipeline_id}",
        )

        self._throw_on_error(res)

    def list_dns_stages(
        self,
        *,
        order_by: Optional[ListDNSStagesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        pipeline_id: Optional[str] = None,
        project_id: Optional[str] = None,
        fqdn: Optional[str] = None,
    ) -> ListDNSStagesResponse:
        """
        List DNS stages.
        List all DNS stages, for a Scaleway Organization or Scaleway Project. By default, the DNS stages returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param order_by: Sort order of DNS stages in the response.
        :param page: Page number to return, from the paginated results.
        :param page_size: Number of DNS stages to return per page.
        :param pipeline_id: Pipeline ID to filter for, only DNS stages from this pipeline will be returned.
        :param project_id: Project ID to filter for, only DNS stages from this Project will be returned.
        :param fqdn: Fully Qualified Domain Name to filter for (in the format subdomain.example.com), only DNS stages with this FQDN will be returned.
        :return: :class:`ListDNSStagesResponse <ListDNSStagesResponse>`

        Usage:
        ::

            result = api.list_dns_stages()
        """

        res = self._request(
            "GET",
            "/edge-services/v1alpha1/dns-stages",
            params={
                "fqdn": fqdn,
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "pipeline_id": pipeline_id,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListDNSStagesResponse(res.json())

    def list_dns_stages_all(
        self,
        *,
        order_by: Optional[ListDNSStagesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        pipeline_id: Optional[str] = None,
        project_id: Optional[str] = None,
        fqdn: Optional[str] = None,
    ) -> List[DNSStage]:
        """
        List DNS stages.
        List all DNS stages, for a Scaleway Organization or Scaleway Project. By default, the DNS stages returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param order_by: Sort order of DNS stages in the response.
        :param page: Page number to return, from the paginated results.
        :param page_size: Number of DNS stages to return per page.
        :param pipeline_id: Pipeline ID to filter for, only DNS stages from this pipeline will be returned.
        :param project_id: Project ID to filter for, only DNS stages from this Project will be returned.
        :param fqdn: Fully Qualified Domain Name to filter for (in the format subdomain.example.com), only DNS stages with this FQDN will be returned.
        :return: :class:`List[DNSStage] <List[DNSStage]>`

        Usage:
        ::

            result = api.list_dns_stages_all()
        """

        return fetch_all_pages(
            type=ListDNSStagesResponse,
            key="stages",
            fetcher=self.list_dns_stages,
            args={
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "pipeline_id": pipeline_id,
                "project_id": project_id,
                "fqdn": fqdn,
            },
        )

    def create_dns_stage(
        self,
        *,
        project_id: Optional[str] = None,
        fqdns: Optional[List[str]] = None,
        tls_stage_id: Optional[str] = None,
        cache_stage_id: Optional[str] = None,
        backend_stage_id: Optional[str] = None,
    ) -> DNSStage:
        """
        Create DNS stage.
        Create a new DNS stage. You must specify the `fqdns` field to customize the domain endpoint, using a domain you already own.
        :param project_id: Project ID in which the DNS stage will be created.
        :param fqdns: Fully Qualified Domain Name (in the format subdomain.example.com) to attach to the stage.
        :param tls_stage_id: TLS stage ID the DNS stage will be linked to.
        One-Of ('next'): at most one of 'tls_stage_id', 'cache_stage_id', 'backend_stage_id' could be set.
        :param cache_stage_id: Cache stage ID the DNS stage will be linked to.
        One-Of ('next'): at most one of 'tls_stage_id', 'cache_stage_id', 'backend_stage_id' could be set.
        :param backend_stage_id: Backend stage ID the DNS stage will be linked to.
        One-Of ('next'): at most one of 'tls_stage_id', 'cache_stage_id', 'backend_stage_id' could be set.
        :return: :class:`DNSStage <DNSStage>`

        Usage:
        ::

            result = api.create_dns_stage()
        """

        res = self._request(
            "POST",
            "/edge-services/v1alpha1/dns-stages",
            body=marshal_CreateDNSStageRequest(
                CreateDNSStageRequest(
                    project_id=project_id,
                    fqdns=fqdns,
                    tls_stage_id=tls_stage_id,
                    cache_stage_id=cache_stage_id,
                    backend_stage_id=backend_stage_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_DNSStage(res.json())

    def get_dns_stage(
        self,
        *,
        dns_stage_id: str,
    ) -> DNSStage:
        """
        Get DNS stage.
        Retrieve information about an existing DNS stage, specified by its `dns_stage_id`. Its full details, including FQDNs, are returned in the response object.
        :param dns_stage_id: ID of the requested DNS stage.
        :return: :class:`DNSStage <DNSStage>`

        Usage:
        ::

            result = api.get_dns_stage(
                dns_stage_id="example",
            )
        """

        param_dns_stage_id = validate_path_param("dns_stage_id", dns_stage_id)

        res = self._request(
            "GET",
            f"/edge-services/v1alpha1/dns-stages/{param_dns_stage_id}",
        )

        self._throw_on_error(res)
        return unmarshal_DNSStage(res.json())

    def update_dns_stage(
        self,
        *,
        dns_stage_id: str,
        fqdns: Optional[List[str]] = None,
        tls_stage_id: Optional[str] = None,
        cache_stage_id: Optional[str] = None,
        backend_stage_id: Optional[str] = None,
    ) -> DNSStage:
        """
        Update DNS stage.
        Update the parameters of an existing DNS stage, specified by its `dns_stage_id`.
        :param dns_stage_id: ID of the DNS stage to update.
        :param fqdns: Fully Qualified Domain Name (in the format subdomain.example.com) attached to the stage.
        :param tls_stage_id: TLS stage ID the DNS stage will be linked to.
        One-Of ('next'): at most one of 'tls_stage_id', 'cache_stage_id', 'backend_stage_id' could be set.
        :param cache_stage_id: Cache stage ID the DNS stage will be linked to.
        One-Of ('next'): at most one of 'tls_stage_id', 'cache_stage_id', 'backend_stage_id' could be set.
        :param backend_stage_id: Backend stage ID the DNS stage will be linked to.
        One-Of ('next'): at most one of 'tls_stage_id', 'cache_stage_id', 'backend_stage_id' could be set.
        :return: :class:`DNSStage <DNSStage>`

        Usage:
        ::

            result = api.update_dns_stage(
                dns_stage_id="example",
            )
        """

        param_dns_stage_id = validate_path_param("dns_stage_id", dns_stage_id)

        res = self._request(
            "PATCH",
            f"/edge-services/v1alpha1/dns-stages/{param_dns_stage_id}",
            body=marshal_UpdateDNSStageRequest(
                UpdateDNSStageRequest(
                    dns_stage_id=dns_stage_id,
                    fqdns=fqdns,
                    tls_stage_id=tls_stage_id,
                    cache_stage_id=cache_stage_id,
                    backend_stage_id=backend_stage_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_DNSStage(res.json())

    def delete_dns_stage(
        self,
        *,
        dns_stage_id: str,
    ) -> None:
        """
        Delete DNS stage.
        Delete an existing DNS stage, specified by its `dns_stage_id`. Deleting a DNS stage is permanent, and cannot be undone.
        :param dns_stage_id: ID of the DNS stage to delete.

        Usage:
        ::

            result = api.delete_dns_stage(
                dns_stage_id="example",
            )
        """

        param_dns_stage_id = validate_path_param("dns_stage_id", dns_stage_id)

        res = self._request(
            "DELETE",
            f"/edge-services/v1alpha1/dns-stages/{param_dns_stage_id}",
        )

        self._throw_on_error(res)

    def list_tls_stages(
        self,
        *,
        order_by: Optional[ListTLSStagesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        pipeline_id: Optional[str] = None,
        project_id: Optional[str] = None,
        secret_id: Optional[str] = None,
        secret_region: Optional[str] = None,
    ) -> ListTLSStagesResponse:
        """
        List TLS stages.
        List all TLS stages, for a Scaleway Organization or Scaleway Project. By default, the TLS stages returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param order_by: Sort order of TLS stages in the response.
        :param page: Page number to return, from the paginated results.
        :param page_size: Number of TLS stages to return per page.
        :param pipeline_id: Pipeline ID to filter for, only TLS stages from this pipeline will be returned.
        :param project_id: Project ID to filter for, only TLS stages from this Project will be returned.
        :param secret_id: Secret ID to filter for, only TLS stages with this Secret ID will be returned.
        :param secret_region: Secret region to filter for, only TLS stages with a Secret in this region will be returned.
        :return: :class:`ListTLSStagesResponse <ListTLSStagesResponse>`

        Usage:
        ::

            result = api.list_tls_stages()
        """

        res = self._request(
            "GET",
            "/edge-services/v1alpha1/tls-stages",
            params={
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "pipeline_id": pipeline_id,
                "project_id": project_id or self.client.default_project_id,
                "secret_id": secret_id,
                "secret_region": secret_region,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListTLSStagesResponse(res.json())

    def list_tls_stages_all(
        self,
        *,
        order_by: Optional[ListTLSStagesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        pipeline_id: Optional[str] = None,
        project_id: Optional[str] = None,
        secret_id: Optional[str] = None,
        secret_region: Optional[str] = None,
    ) -> List[TLSStage]:
        """
        List TLS stages.
        List all TLS stages, for a Scaleway Organization or Scaleway Project. By default, the TLS stages returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param order_by: Sort order of TLS stages in the response.
        :param page: Page number to return, from the paginated results.
        :param page_size: Number of TLS stages to return per page.
        :param pipeline_id: Pipeline ID to filter for, only TLS stages from this pipeline will be returned.
        :param project_id: Project ID to filter for, only TLS stages from this Project will be returned.
        :param secret_id: Secret ID to filter for, only TLS stages with this Secret ID will be returned.
        :param secret_region: Secret region to filter for, only TLS stages with a Secret in this region will be returned.
        :return: :class:`List[TLSStage] <List[TLSStage]>`

        Usage:
        ::

            result = api.list_tls_stages_all()
        """

        return fetch_all_pages(
            type=ListTLSStagesResponse,
            key="stages",
            fetcher=self.list_tls_stages,
            args={
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "pipeline_id": pipeline_id,
                "project_id": project_id,
                "secret_id": secret_id,
                "secret_region": secret_region,
            },
        )

    def create_tls_stage(
        self,
        *,
        project_id: Optional[str] = None,
        secrets: Optional[List[TLSSecret]] = None,
        managed_certificate: Optional[bool] = None,
        cache_stage_id: Optional[str] = None,
        backend_stage_id: Optional[str] = None,
    ) -> TLSStage:
        """
        Create TLS stage.
        Create a new TLS stage. You must specify either the `secrets` or `managed_certificate` fields to customize the SSL/TLS certificate of your endpoint. Choose `secrets` if you are using a pre-existing certificate held in Scaleway Secret Manager, or `managed_certificate` to let Scaleway generate and manage a Let's Encrypt certificate for your customized endpoint.
        :param project_id: Project ID in which the TLS stage will be created.
        :param secrets: Secret (from Scaleway Secret Manager) containing your custom certificate.
        :param managed_certificate: True when Scaleway generates and manages a Let's Encrypt certificate for the TLS stage/custom endpoint.
        :param cache_stage_id: Cache stage ID the TLS stage will be linked to.
        One-Of ('next'): at most one of 'cache_stage_id', 'backend_stage_id' could be set.
        :param backend_stage_id: Backend stage ID the TLS stage will be linked to.
        One-Of ('next'): at most one of 'cache_stage_id', 'backend_stage_id' could be set.
        :return: :class:`TLSStage <TLSStage>`

        Usage:
        ::

            result = api.create_tls_stage()
        """

        res = self._request(
            "POST",
            "/edge-services/v1alpha1/tls-stages",
            body=marshal_CreateTLSStageRequest(
                CreateTLSStageRequest(
                    project_id=project_id,
                    secrets=secrets,
                    managed_certificate=managed_certificate,
                    cache_stage_id=cache_stage_id,
                    backend_stage_id=backend_stage_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_TLSStage(res.json())

    def get_tls_stage(
        self,
        *,
        tls_stage_id: str,
    ) -> TLSStage:
        """
        Get TLS stage.
        Retrieve information about an existing TLS stage, specified by its `tls_stage_id`. Its full details, including secrets and certificate expiration date are returned in the response object.
        :param tls_stage_id: ID of the requested TLS stage.
        :return: :class:`TLSStage <TLSStage>`

        Usage:
        ::

            result = api.get_tls_stage(
                tls_stage_id="example",
            )
        """

        param_tls_stage_id = validate_path_param("tls_stage_id", tls_stage_id)

        res = self._request(
            "GET",
            f"/edge-services/v1alpha1/tls-stages/{param_tls_stage_id}",
        )

        self._throw_on_error(res)
        return unmarshal_TLSStage(res.json())

    def update_tls_stage(
        self,
        *,
        tls_stage_id: str,
        tls_secrets_config: Optional[TLSSecretsConfig] = None,
        managed_certificate: Optional[bool] = None,
        cache_stage_id: Optional[str] = None,
        backend_stage_id: Optional[str] = None,
    ) -> TLSStage:
        """
        Update TLS stage.
        Update the parameters of an existing TLS stage, specified by its `tls_stage_id`. Both `tls_secrets_config` and `managed_certificate` parameters can be updated.
        :param tls_stage_id: ID of the TLS stage to update.
        :param tls_secrets_config: Secret (from Scaleway Secret-Manager) containing your custom certificate.
        :param managed_certificate: True when Scaleway generates and manages a Let's Encrypt certificate for the TLS stage/custom endpoint.
        :param cache_stage_id: Cache stage ID the TLS stage will be linked to.
        One-Of ('next'): at most one of 'cache_stage_id', 'backend_stage_id' could be set.
        :param backend_stage_id: Backend stage ID the TLS stage will be linked to.
        One-Of ('next'): at most one of 'cache_stage_id', 'backend_stage_id' could be set.
        :return: :class:`TLSStage <TLSStage>`

        Usage:
        ::

            result = api.update_tls_stage(
                tls_stage_id="example",
            )
        """

        param_tls_stage_id = validate_path_param("tls_stage_id", tls_stage_id)

        res = self._request(
            "PATCH",
            f"/edge-services/v1alpha1/tls-stages/{param_tls_stage_id}",
            body=marshal_UpdateTLSStageRequest(
                UpdateTLSStageRequest(
                    tls_stage_id=tls_stage_id,
                    tls_secrets_config=tls_secrets_config,
                    managed_certificate=managed_certificate,
                    cache_stage_id=cache_stage_id,
                    backend_stage_id=backend_stage_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_TLSStage(res.json())

    def delete_tls_stage(
        self,
        *,
        tls_stage_id: str,
    ) -> None:
        """
        Delete TLS stage.
        Delete an existing TLS stage, specified by its `tls_stage_id`. Deleting a TLS stage is permanent, and cannot be undone.
        :param tls_stage_id: ID of the TLS stage to delete.

        Usage:
        ::

            result = api.delete_tls_stage(
                tls_stage_id="example",
            )
        """

        param_tls_stage_id = validate_path_param("tls_stage_id", tls_stage_id)

        res = self._request(
            "DELETE",
            f"/edge-services/v1alpha1/tls-stages/{param_tls_stage_id}",
        )

        self._throw_on_error(res)

    def list_cache_stages(
        self,
        *,
        order_by: Optional[ListCacheStagesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        pipeline_id: Optional[str] = None,
        project_id: Optional[str] = None,
    ) -> ListCacheStagesResponse:
        """
        List cache stages.
        List all cache stages, for a Scaleway Organization or Scaleway Project. By default, the cache stages returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param order_by: Sort order of cache stages in the response.
        :param page: Page number to return, from the paginated results.
        :param page_size: Number of cache stages to return per page.
        :param pipeline_id: Pipeline ID to filter for, only cache stages from this pipeline will be returned.
        :param project_id: Project ID to filter for, only cache stages from this Project will be returned.
        :return: :class:`ListCacheStagesResponse <ListCacheStagesResponse>`

        Usage:
        ::

            result = api.list_cache_stages()
        """

        res = self._request(
            "GET",
            "/edge-services/v1alpha1/cache-stages",
            params={
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "pipeline_id": pipeline_id,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListCacheStagesResponse(res.json())

    def list_cache_stages_all(
        self,
        *,
        order_by: Optional[ListCacheStagesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        pipeline_id: Optional[str] = None,
        project_id: Optional[str] = None,
    ) -> List[CacheStage]:
        """
        List cache stages.
        List all cache stages, for a Scaleway Organization or Scaleway Project. By default, the cache stages returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param order_by: Sort order of cache stages in the response.
        :param page: Page number to return, from the paginated results.
        :param page_size: Number of cache stages to return per page.
        :param pipeline_id: Pipeline ID to filter for, only cache stages from this pipeline will be returned.
        :param project_id: Project ID to filter for, only cache stages from this Project will be returned.
        :return: :class:`List[CacheStage] <List[CacheStage]>`

        Usage:
        ::

            result = api.list_cache_stages_all()
        """

        return fetch_all_pages(
            type=ListCacheStagesResponse,
            key="stages",
            fetcher=self.list_cache_stages,
            args={
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "pipeline_id": pipeline_id,
                "project_id": project_id,
            },
        )

    def create_cache_stage(
        self,
        *,
        project_id: Optional[str] = None,
        fallback_ttl: Optional[str] = None,
        backend_stage_id: Optional[str] = None,
    ) -> CacheStage:
        """
        Create cache stage.
        Create a new cache stage. You must specify the `fallback_ttl` field to customize the TTL of the cache.
        :param project_id: Project ID in which the cache stage will be created.
        :param fallback_ttl: Time To Live (TTL) in seconds. Defines how long content is cached.
        :param backend_stage_id: Backend stage ID the cache stage will be linked to.
        One-Of ('next'): at most one of 'backend_stage_id' could be set.
        :return: :class:`CacheStage <CacheStage>`

        Usage:
        ::

            result = api.create_cache_stage()
        """

        res = self._request(
            "POST",
            "/edge-services/v1alpha1/cache-stages",
            body=marshal_CreateCacheStageRequest(
                CreateCacheStageRequest(
                    project_id=project_id,
                    fallback_ttl=fallback_ttl,
                    backend_stage_id=backend_stage_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_CacheStage(res.json())

    def get_cache_stage(
        self,
        *,
        cache_stage_id: str,
    ) -> CacheStage:
        """
        Get cache stage.
        Retrieve information about an existing cache stage, specified by its `cache_stage_id`. Its full details, including Time To Live (TTL), are returned in the response object.
        :param cache_stage_id: ID of the requested cache stage.
        :return: :class:`CacheStage <CacheStage>`

        Usage:
        ::

            result = api.get_cache_stage(
                cache_stage_id="example",
            )
        """

        param_cache_stage_id = validate_path_param("cache_stage_id", cache_stage_id)

        res = self._request(
            "GET",
            f"/edge-services/v1alpha1/cache-stages/{param_cache_stage_id}",
        )

        self._throw_on_error(res)
        return unmarshal_CacheStage(res.json())

    def update_cache_stage(
        self,
        *,
        cache_stage_id: str,
        fallback_ttl: Optional[str] = None,
        backend_stage_id: Optional[str] = None,
    ) -> CacheStage:
        """
        Update cache stage.
        Update the parameters of an existing cache stage, specified by its `cache_stage_id`. Parameters which can be updated include the `fallback_ttl` and `backend_stage_id`.
        :param cache_stage_id: ID of the cache stage to update.
        :param fallback_ttl: Time To Live (TTL) in seconds. Defines how long content is cached.
        :param backend_stage_id: Backend stage ID the cache stage will be linked to.
        One-Of ('next'): at most one of 'backend_stage_id' could be set.
        :return: :class:`CacheStage <CacheStage>`

        Usage:
        ::

            result = api.update_cache_stage(
                cache_stage_id="example",
            )
        """

        param_cache_stage_id = validate_path_param("cache_stage_id", cache_stage_id)

        res = self._request(
            "PATCH",
            f"/edge-services/v1alpha1/cache-stages/{param_cache_stage_id}",
            body=marshal_UpdateCacheStageRequest(
                UpdateCacheStageRequest(
                    cache_stage_id=cache_stage_id,
                    fallback_ttl=fallback_ttl,
                    backend_stage_id=backend_stage_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_CacheStage(res.json())

    def delete_cache_stage(
        self,
        *,
        cache_stage_id: str,
    ) -> None:
        """
        Delete cache stage.
        Delete an existing cache stage, specified by its `cache_stage_id`. Deleting a cache stage is permanent, and cannot be undone.
        :param cache_stage_id: ID of the cache stage to delete.

        Usage:
        ::

            result = api.delete_cache_stage(
                cache_stage_id="example",
            )
        """

        param_cache_stage_id = validate_path_param("cache_stage_id", cache_stage_id)

        res = self._request(
            "DELETE",
            f"/edge-services/v1alpha1/cache-stages/{param_cache_stage_id}",
        )

        self._throw_on_error(res)

    def list_backend_stages(
        self,
        *,
        order_by: Optional[ListBackendStagesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        pipeline_id: Optional[str] = None,
        project_id: Optional[str] = None,
        bucket_name: Optional[str] = None,
        bucket_region: Optional[str] = None,
        lb_id: Optional[str] = None,
    ) -> ListBackendStagesResponse:
        """
        List backend stages.
        List all backend stages, for a Scaleway Organization or Scaleway Project. By default, the backend stages returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param order_by: Sort order of backend stages in the response.
        :param page: Page number to return, from the paginated results.
        :param page_size: Number of backend stages to return per page.
        :param pipeline_id: Pipeline ID to filter for, only backend stages from this pipeline will be returned.
        :param project_id: Project ID to filter for, only backend stages from this Project will be returned.
        :param bucket_name: Bucket name to filter for, only backend stages from this Bucket will be returned.
        :param bucket_region: Bucket region to filter for, only backend stages with buckets in this region will be returned.
        :param lb_id: Load Balancer ID to filter for, only backend stages with this Load Balancer will be returned.
        :return: :class:`ListBackendStagesResponse <ListBackendStagesResponse>`

        Usage:
        ::

            result = api.list_backend_stages()
        """

        res = self._request(
            "GET",
            "/edge-services/v1alpha1/backend-stages",
            params={
                "bucket_name": bucket_name,
                "bucket_region": bucket_region,
                "lb_id": lb_id,
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "pipeline_id": pipeline_id,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListBackendStagesResponse(res.json())

    def list_backend_stages_all(
        self,
        *,
        order_by: Optional[ListBackendStagesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        pipeline_id: Optional[str] = None,
        project_id: Optional[str] = None,
        bucket_name: Optional[str] = None,
        bucket_region: Optional[str] = None,
        lb_id: Optional[str] = None,
    ) -> List[BackendStage]:
        """
        List backend stages.
        List all backend stages, for a Scaleway Organization or Scaleway Project. By default, the backend stages returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param order_by: Sort order of backend stages in the response.
        :param page: Page number to return, from the paginated results.
        :param page_size: Number of backend stages to return per page.
        :param pipeline_id: Pipeline ID to filter for, only backend stages from this pipeline will be returned.
        :param project_id: Project ID to filter for, only backend stages from this Project will be returned.
        :param bucket_name: Bucket name to filter for, only backend stages from this Bucket will be returned.
        :param bucket_region: Bucket region to filter for, only backend stages with buckets in this region will be returned.
        :param lb_id: Load Balancer ID to filter for, only backend stages with this Load Balancer will be returned.
        :return: :class:`List[BackendStage] <List[BackendStage]>`

        Usage:
        ::

            result = api.list_backend_stages_all()
        """

        return fetch_all_pages(
            type=ListBackendStagesResponse,
            key="stages",
            fetcher=self.list_backend_stages,
            args={
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "pipeline_id": pipeline_id,
                "project_id": project_id,
                "bucket_name": bucket_name,
                "bucket_region": bucket_region,
                "lb_id": lb_id,
            },
        )

    def create_backend_stage(
        self,
        *,
        project_id: Optional[str] = None,
        scaleway_s3: Optional[ScalewayS3BackendConfig] = None,
        scaleway_lb: Optional[ScalewayLbBackendConfig] = None,
    ) -> BackendStage:
        """
        Create backend stage.
        Create a new backend stage. You must specify either a `scaleway_s3` (for a Scaleway Object Storage bucket) or `scaleway_lb` (for a Scaleway Load Balancer) field to configure the origin.
        :param project_id: Project ID in which the backend stage will be created.
        :param scaleway_s3: Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        One-Of ('backend_config'): at most one of 'scaleway_s3', 'scaleway_lb' could be set.
        :param scaleway_lb: Scaleway Load Balancer origin linked to the backend stage.
        One-Of ('backend_config'): at most one of 'scaleway_s3', 'scaleway_lb' could be set.
        :return: :class:`BackendStage <BackendStage>`

        Usage:
        ::

            result = api.create_backend_stage()
        """

        res = self._request(
            "POST",
            "/edge-services/v1alpha1/backend-stages",
            body=marshal_CreateBackendStageRequest(
                CreateBackendStageRequest(
                    project_id=project_id,
                    scaleway_s3=scaleway_s3,
                    scaleway_lb=scaleway_lb,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_BackendStage(res.json())

    def get_backend_stage(
        self,
        *,
        backend_stage_id: str,
    ) -> BackendStage:
        """
        Get backend stage.
        Retrieve information about an existing backend stage, specified by its `backend_stage_id`. Its full details, including `scaleway_s3` or `scaleway_lb`, are returned in the response object.
        :param backend_stage_id: ID of the requested backend stage.
        :return: :class:`BackendStage <BackendStage>`

        Usage:
        ::

            result = api.get_backend_stage(
                backend_stage_id="example",
            )
        """

        param_backend_stage_id = validate_path_param(
            "backend_stage_id", backend_stage_id
        )

        res = self._request(
            "GET",
            f"/edge-services/v1alpha1/backend-stages/{param_backend_stage_id}",
        )

        self._throw_on_error(res)
        return unmarshal_BackendStage(res.json())

    def update_backend_stage(
        self,
        *,
        backend_stage_id: str,
        scaleway_s3: Optional[ScalewayS3BackendConfig] = None,
        scaleway_lb: Optional[ScalewayLbBackendConfig] = None,
    ) -> BackendStage:
        """
        Update backend stage.
        Update the parameters of an existing backend stage, specified by its `backend_stage_id`.
        :param backend_stage_id: ID of the backend stage to update.
        :param scaleway_s3: Scaleway Object Storage origin bucket (S3) linked to the backend stage.
        One-Of ('backend_config'): at most one of 'scaleway_s3', 'scaleway_lb' could be set.
        :param scaleway_lb: Scaleway Load Balancer origin linked to the backend stage.
        One-Of ('backend_config'): at most one of 'scaleway_s3', 'scaleway_lb' could be set.
        :return: :class:`BackendStage <BackendStage>`

        Usage:
        ::

            result = api.update_backend_stage(
                backend_stage_id="example",
            )
        """

        param_backend_stage_id = validate_path_param(
            "backend_stage_id", backend_stage_id
        )

        res = self._request(
            "PATCH",
            f"/edge-services/v1alpha1/backend-stages/{param_backend_stage_id}",
            body=marshal_UpdateBackendStageRequest(
                UpdateBackendStageRequest(
                    backend_stage_id=backend_stage_id,
                    scaleway_s3=scaleway_s3,
                    scaleway_lb=scaleway_lb,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_BackendStage(res.json())

    def delete_backend_stage(
        self,
        *,
        backend_stage_id: str,
    ) -> None:
        """
        Delete backend stage.
        Delete an existing backend stage, specified by its `backend_stage_id`. Deleting a backend stage is permanent, and cannot be undone.
        :param backend_stage_id: ID of the backend stage to delete.

        Usage:
        ::

            result = api.delete_backend_stage(
                backend_stage_id="example",
            )
        """

        param_backend_stage_id = validate_path_param(
            "backend_stage_id", backend_stage_id
        )

        res = self._request(
            "DELETE",
            f"/edge-services/v1alpha1/backend-stages/{param_backend_stage_id}",
        )

        self._throw_on_error(res)

    def check_domain(
        self,
        *,
        fqdn: str,
        cname: str,
        project_id: Optional[str] = None,
    ) -> CheckDomainResponse:
        """
        :param fqdn:
        :param cname:
        :param project_id:
        :return: :class:`CheckDomainResponse <CheckDomainResponse>`

        Usage:
        ::

            result = api.check_domain(
                fqdn="example",
                cname="example",
            )
        """

        res = self._request(
            "POST",
            "/edge-services/v1alpha1/check-domain",
            body=marshal_CheckDomainRequest(
                CheckDomainRequest(
                    fqdn=fqdn,
                    cname=cname,
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_CheckDomainResponse(res.json())

    def check_pem_chain(
        self,
        *,
        fqdn: str,
        project_id: Optional[str] = None,
        secret: Optional[CheckPEMChainRequestSecretChain] = None,
        raw: Optional[str] = None,
    ) -> CheckPEMChainResponse:
        """
        :param fqdn:
        :param project_id:
        :param secret:
        One-Of ('chain'): at most one of 'secret', 'raw' could be set.
        :param raw:
        One-Of ('chain'): at most one of 'secret', 'raw' could be set.
        :return: :class:`CheckPEMChainResponse <CheckPEMChainResponse>`

        Usage:
        ::

            result = api.check_pem_chain(
                fqdn="example",
            )
        """

        res = self._request(
            "POST",
            "/edge-services/v1alpha1/check-pem-chain",
            body=marshal_CheckPEMChainRequest(
                CheckPEMChainRequest(
                    fqdn=fqdn,
                    project_id=project_id,
                    secret=secret,
                    raw=raw,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_CheckPEMChainResponse(res.json())

    def list_purge_requests(
        self,
        *,
        order_by: Optional[ListPurgeRequestsRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        organization_id: Optional[str] = None,
        project_id: Optional[str] = None,
        pipeline_id: Optional[str] = None,
    ) -> ListPurgeRequestsResponse:
        """
        List purge requests.
        List all purge requests, for a Scaleway Organization or Scaleway Project. This enables you to retrieve a history of all previously-made purge requests. By default, the purge requests returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param order_by: Sort order of purge requests in the response.
        :param page: Page number to return, from the paginated results.
        :param page_size: Number of purge requests to return per page.
        :param organization_id: Organization ID to filter for, only purge requests from this Project will be returned.
        :param project_id: Project ID to filter for, only purge requests from this Project will be returned.
        :param pipeline_id: Pipeline ID to filter for, only purge requests from this pipeline will be returned.
        :return: :class:`ListPurgeRequestsResponse <ListPurgeRequestsResponse>`

        Usage:
        ::

            result = api.list_purge_requests()
        """

        res = self._request(
            "GET",
            "/edge-services/v1alpha1/purge-requests",
            params={
                "order_by": order_by,
                "organization_id": organization_id
                or self.client.default_organization_id,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "pipeline_id": pipeline_id,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListPurgeRequestsResponse(res.json())

    def list_purge_requests_all(
        self,
        *,
        order_by: Optional[ListPurgeRequestsRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        organization_id: Optional[str] = None,
        project_id: Optional[str] = None,
        pipeline_id: Optional[str] = None,
    ) -> List[PurgeRequest]:
        """
        List purge requests.
        List all purge requests, for a Scaleway Organization or Scaleway Project. This enables you to retrieve a history of all previously-made purge requests. By default, the purge requests returned in the list are ordered by creation date in ascending order, though this can be modified via the `order_by` field.
        :param order_by: Sort order of purge requests in the response.
        :param page: Page number to return, from the paginated results.
        :param page_size: Number of purge requests to return per page.
        :param organization_id: Organization ID to filter for, only purge requests from this Project will be returned.
        :param project_id: Project ID to filter for, only purge requests from this Project will be returned.
        :param pipeline_id: Pipeline ID to filter for, only purge requests from this pipeline will be returned.
        :return: :class:`List[PurgeRequest] <List[PurgeRequest]>`

        Usage:
        ::

            result = api.list_purge_requests_all()
        """

        return fetch_all_pages(
            type=ListPurgeRequestsResponse,
            key="purge_requests",
            fetcher=self.list_purge_requests,
            args={
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "organization_id": organization_id,
                "project_id": project_id,
                "pipeline_id": pipeline_id,
            },
        )

    def create_purge_request(
        self,
        *,
        pipeline_id: str,
        assets: Optional[List[str]] = None,
        all: Optional[bool] = None,
    ) -> PurgeRequest:
        """
        Create purge request.
        Create a new purge request. You must specify either the `all` field (to purge all content) or a list of `assets` (to define the precise assets to purge).
        :param pipeline_id: Pipeline ID in which the purge request will be created.
        :param assets: List of asserts to purge.
        One-Of ('target'): at most one of 'assets', 'all' could be set.
        :param all: Defines whether to purge all content.
        One-Of ('target'): at most one of 'assets', 'all' could be set.
        :return: :class:`PurgeRequest <PurgeRequest>`

        Usage:
        ::

            result = api.create_purge_request(
                pipeline_id="example",
            )
        """

        res = self._request(
            "POST",
            "/edge-services/v1alpha1/purge-requests",
            body=marshal_CreatePurgeRequestRequest(
                CreatePurgeRequestRequest(
                    pipeline_id=pipeline_id,
                    assets=assets,
                    all=all,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_PurgeRequest(res.json())

    def get_purge_request(
        self,
        *,
        purge_request_id: str,
    ) -> PurgeRequest:
        """
        Get purge request.
        Retrieve information about a purge request, specified by its `purge_request_id`. Its full details, including `status` and `target`, are returned in the response object.
        :param purge_request_id: ID of the requested purge request.
        :return: :class:`PurgeRequest <PurgeRequest>`

        Usage:
        ::

            result = api.get_purge_request(
                purge_request_id="example",
            )
        """

        param_purge_request_id = validate_path_param(
            "purge_request_id", purge_request_id
        )

        res = self._request(
            "GET",
            f"/edge-services/v1alpha1/purge-requests/{param_purge_request_id}",
        )

        self._throw_on_error(res)
        return unmarshal_PurgeRequest(res.json())

    def wait_for_purge_request(
        self,
        *,
        purge_request_id: str,
        options: Optional[WaitForOptions[PurgeRequest, bool]] = None,
    ) -> PurgeRequest:
        """
        Get purge request.
        Retrieve information about a purge request, specified by its `purge_request_id`. Its full details, including `status` and `target`, are returned in the response object.
        :param purge_request_id: ID of the requested purge request.
        :return: :class:`PurgeRequest <PurgeRequest>`

        Usage:
        ::

            result = api.get_purge_request(
                purge_request_id="example",
            )
        """

        if not options:
            options = WaitForOptions()

        if not options.stop:
            options.stop = (
                lambda res: res.status not in PURGE_REQUEST_TRANSIENT_STATUSES
            )

        return wait_for_resource(
            fetcher=self.get_purge_request,
            options=options,
            args={
                "purge_request_id": purge_request_id,
            },
        )

    def check_lb_origin(
        self,
        *,
        lb: Optional[ScalewayLb] = None,
    ) -> CheckLbOriginResponse:
        """
        :param lb:
        :return: :class:`CheckLbOriginResponse <CheckLbOriginResponse>`

        Usage:
        ::

            result = api.check_lb_origin()
        """

        res = self._request(
            "POST",
            "/edge-services/v1alpha1/check-lb-origin",
            body=marshal_CheckLbOriginRequest(
                CheckLbOriginRequest(
                    lb=lb,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_CheckLbOriginResponse(res.json())



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.

from typing import Any, Dict
from dateutil import parser

from scaleway_core.profile import ProfileDefaults
from scaleway_core.bridge import (
    unmarshal_Money,
)
from .types import (
    OfferQuotaWarning,
    HostingCpanelUrls,
    HostingOption,
    Hosting,
    CheckUserOwnsDomainResponse,
    DnsRecord,
    Nameserver,
    DnsRecords,
    ControlPanel,
    ListControlPanelsResponse,
    ListHostingsResponse,
    OfferProduct,
    Offer,
    ListOffersResponse,
    ResetHostingPasswordResponse,
    Session,
    CheckUserOwnsDomainRequest,
    CreateHostingRequestDomainConfiguration,
    CreateHostingRequest,
    UpdateHostingRequest,
)
from ...std.types import (
    LanguageCode as StdLanguageCode,
)


def unmarshal_HostingCpanelUrls(data: Any) -> HostingCpanelUrls:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'HostingCpanelUrls' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("dashboard", None)
    if field is not None:
        args["dashboard"] = field

    field = data.get("webmail", None)
    if field is not None:
        args["webmail"] = field

    return HostingCpanelUrls(**args)


def unmarshal_HostingOption(data: Any) -> HostingOption:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'HostingOption' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    return HostingOption(**args)


def unmarshal_Hosting(data: Any) -> Hosting:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Hosting' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("organization_id", None)
    if field is not None:
        args["organization_id"] = field

    field = data.get("project_id", None)
    if field is not None:
        args["project_id"] = field

    field = data.get("status", None)
    if field is not None:
        args["status"] = field

    field = data.get("platform_hostname", None)
    if field is not None:
        args["platform_hostname"] = field

    field = data.get("offer_id", None)
    if field is not None:
        args["offer_id"] = field

    field = data.get("offer_name", None)
    if field is not None:
        args["offer_name"] = field

    field = data.get("domain", None)
    if field is not None:
        args["domain"] = field

    field = data.get("tags", None)
    if field is not None:
        args["tags"] = field

    field = data.get("updated_at", None)
    if field is not None:
        args["updated_at"] = parser.isoparse(field) if isinstance(field, str) else field
    else:
        args["updated_at"] = None

    field = data.get("created_at", None)
    if field is not None:
        args["created_at"] = parser.isoparse(field) if isinstance(field, str) else field
    else:
        args["created_at"] = None

    field = data.get("platform_number", None)
    if field is not None:
        args["platform_number"] = field
    else:
        args["platform_number"] = None

    field = data.get("options", None)
    if field is not None:
        args["options"] = (
            [unmarshal_HostingOption(v) for v in field] if field is not None else None
        )

    field = data.get("dns_status", None)
    if field is not None:
        args["dns_status"] = field

    field = data.get("username", None)
    if field is not None:
        args["username"] = field

    field = data.get("offer_end_of_life", None)
    if field is not None:
        args["offer_end_of_life"] = field

    field = data.get("control_panel_name", None)
    if field is not None:
        args["control_panel_name"] = field

    field = data.get("platform_group", None)
    if field is not None:
        args["platform_group"] = field

    field = data.get("ipv4", None)
    if field is not None:
        args["ipv4"] = field

    field = data.get("ipv6", None)
    if field is not None:
        args["ipv6"] = field

    field = data.get("protected", None)
    if field is not None:
        args["protected"] = field

    field = data.get("one_time_password", None)
    if field is not None:
        args["one_time_password"] = field

    field = data.get("region", None)
    if field is not None:
        args["region"] = field

    field = data.get("cpanel_urls", None)
    if field is not None:
        args["cpanel_urls"] = unmarshal_HostingCpanelUrls(field)
    else:
        args["cpanel_urls"] = None

    return Hosting(**args)


def unmarshal_CheckUserOwnsDomainResponse(data: Any) -> CheckUserOwnsDomainResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'CheckUserOwnsDomainResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("owns_domain", None)
    if field is not None:
        args["owns_domain"] = field

    return CheckUserOwnsDomainResponse(**args)


def unmarshal_DnsRecord(data: Any) -> DnsRecord:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'DnsRecord' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("type", None)
    if field is not None:
        args["type_"] = field

    field = data.get("ttl", None)
    if field is not None:
        args["ttl"] = field

    field = data.get("value", None)
    if field is not None:
        args["value"] = field

    field = data.get("status", None)
    if field is not None:
        args["status"] = field

    field = data.get("priority", None)
    if field is not None:
        args["priority"] = field
    else:
        args["priority"] = None

    return DnsRecord(**args)


def unmarshal_Nameserver(data: Any) -> Nameserver:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Nameserver' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("hostname", None)
    if field is not None:
        args["hostname"] = field

    field = data.get("status", None)
    if field is not None:
        args["status"] = field

    field = data.get("is_default", None)
    if field is not None:
        args["is_default"] = field

    return Nameserver(**args)


def unmarshal_DnsRecords(data: Any) -> DnsRecords:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'DnsRecords' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("records", None)
    if field is not None:
        args["records"] = (
            [unmarshal_DnsRecord(v) for v in field] if field is not None else None
        )

    field = data.get("name_servers", None)
    if field is not None:
        args["name_servers"] = (
            [unmarshal_Nameserver(v) for v in field] if field is not None else None
        )

    field = data.get("status", None)
    if field is not None:
        args["status"] = field

    return DnsRecords(**args)


def unmarshal_ControlPanel(data: Any) -> ControlPanel:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ControlPanel' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("available", None)
    if field is not None:
        args["available"] = field

    field = data.get("logo_url", None)
    if field is not None:
        args["logo_url"] = field

    field = data.get("available_languages", None)
    if field is not None:
        args["available_languages"] = (
            [StdLanguageCode(v) for v in field] if field is not None else None
        )

    return ControlPanel(**args)


def unmarshal_ListControlPanelsResponse(data: Any) -> ListControlPanelsResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListControlPanelsResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    field = data.get("control_panels", None)
    if field is not None:
        args["control_panels"] = (
            [unmarshal_ControlPanel(v) for v in field] if field is not None else None
        )

    return ListControlPanelsResponse(**args)


def unmarshal_ListHostingsResponse(data: Any) -> ListHostingsResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListHostingsResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    field = data.get("hostings", None)
    if field is not None:
        args["hostings"] = (
            [unmarshal_Hosting(v) for v in field] if field is not None else None
        )

    return ListHostingsResponse(**args)


def unmarshal_OfferProduct(data: Any) -> OfferProduct:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'OfferProduct' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("option", None)
    if field is not None:
        args["option"] = field

    field = data.get("email_accounts_quota", None)
    if field is not None:
        args["email_accounts_quota"] = field

    field = data.get("email_storage_quota", None)
    if field is not None:
        args["email_storage_quota"] = field

    field = data.get("databases_quota", None)
    if field is not None:
        args["databases_quota"] = field

    field = data.get("hosting_storage_quota", None)
    if field is not None:
        args["hosting_storage_quota"] = field

    field = data.get("support_included", None)
    if field is not None:
        args["support_included"] = field

    field = data.get("v_cpu", None)
    if field is not None:
        args["v_cpu"] = field

    field = data.get("ram", None)
    if field is not None:
        args["ram"] = field

    field = data.get("max_addon_domains", None)
    if field is not None:
        args["max_addon_domains"] = field

    return OfferProduct(**args)


def unmarshal_Offer(data: Any) -> Offer:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Offer' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("billing_operation_path", None)
    if field is not None:
        args["billing_operation_path"] = field

    field = data.get("available", None)
    if field is not None:
        args["available"] = field

    field = data.get("quota_warnings", None)
    if field is not None:
        args["quota_warnings"] = (
            [OfferQuotaWarning(v) for v in field] if field is not None else None
        )

    field = data.get("end_of_life", None)
    if field is not None:
        args["end_of_life"] = field

    field = data.get("control_panel_name", None)
    if field is not None:
        args["control_panel_name"] = field

    field = data.get("product", None)
    if field is not None:
        args["product"] = unmarshal_OfferProduct(field)
    else:
        args["product"] = None

    field = data.get("price", None)
    if field is not None:
        args["price"] = unmarshal_Money(field)
    else:
        args["price"] = None

    return Offer(**args)


def unmarshal_ListOffersResponse(data: Any) -> ListOffersResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListOffersResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("offers", None)
    if field is not None:
        args["offers"] = (
            [unmarshal_Offer(v) for v in field] if field is not None else None
        )

    return ListOffersResponse(**args)


def unmarshal_ResetHostingPasswordResponse(data: Any) -> ResetHostingPasswordResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ResetHostingPasswordResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("password", None)
    if field is not None:
        args["password"] = field

    return ResetHostingPasswordResponse(**args)


def unmarshal_Session(data: Any) -> Session:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Session' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("url", None)
    if field is not None:
        args["url"] = field

    return Session(**args)


def marshal_CheckUserOwnsDomainRequest(
    request: CheckUserOwnsDomainRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.project_id is not None:
        output["project_id"] = request.project_id or defaults.default_project_id

    return output


def marshal_CreateHostingRequestDomainConfiguration(
    request: CreateHostingRequestDomainConfiguration,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.update_nameservers is not None:
        output["update_nameservers"] = request.update_nameservers

    if request.update_web_record is not None:
        output["update_web_record"] = request.update_web_record

    if request.update_mail_record is not None:
        output["update_mail_record"] = request.update_mail_record

    if request.update_all_records is not None:
        output["update_all_records"] = request.update_all_records

    return output


def marshal_CreateHostingRequest(
    request: CreateHostingRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.offer_id is not None:
        output["offer_id"] = request.offer_id

    if request.domain is not None:
        output["domain"] = request.domain

    if request.project_id is not None:
        output["project_id"] = request.project_id or defaults.default_project_id

    if request.email is not None:
        output["email"] = request.email

    if request.tags is not None:
        output["tags"] = request.tags

    if request.option_ids is not None:
        output["option_ids"] = request.option_ids

    if request.language is not None:
        output["language"] = str(request.language)

    if request.domain_configuration is not None:
        output["domain_configuration"] = (
            marshal_CreateHostingRequestDomainConfiguration(
                request.domain_configuration, defaults
            )
        )

    return output


def marshal_UpdateHostingRequest(
    request: UpdateHostingRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.email is not None:
        output["email"] = request.email

    if request.tags is not None:
        output["tags"] = request.tags

    if request.option_ids is not None:
        output["option_ids"] = request.option_ids

    if request.offer_id is not None:
        output["offer_id"] = request.offer_id

    if request.protected is not None:
        output["protected"] = request.protected

    return output



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from typing import List

from .types import (
    JobStatus,
    ProcessStatus,
    SessionStatus,
)

JOB_TRANSIENT_STATUSES: List[JobStatus] = [
    JobStatus.WAITING,
    JobStatus.RUNNING,
    JobStatus.CANCELLING,
]
"""
Lists transient statutes of the enum :class:`JobStatus <JobStatus>`.
"""
PROCESS_TRANSIENT_STATUSES: List[ProcessStatus] = [
    ProcessStatus.STARTING,
    ProcessStatus.RUNNING,
    ProcessStatus.CANCELLING,
]
"""
Lists transient statutes of the enum :class:`ProcessStatus <ProcessStatus>`.
"""
SESSION_TRANSIENT_STATUSES: List[SessionStatus] = [
    SessionStatus.STARTING,
    SessionStatus.STOPPING,
]
"""
Lists transient statutes of the enum :class:`SessionStatus <SessionStatus>`.
"""



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import ListProjectsRequestOrderBy
from .types import Project
from .types import ListProjectsResponse
from .types import ProjectApiCreateProjectRequest
from .types import ProjectApiDeleteProjectRequest
from .types import ProjectApiGetProjectRequest
from .types import ProjectApiListProjectsRequest
from .types import ProjectApiUpdateProjectRequest
from .api import AccountV3ProjectAPI

__all__ = [
    "ListProjectsRequestOrderBy",
    "Project",
    "ListProjectsResponse",
    "ProjectApiCreateProjectRequest",
    "ProjectApiDeleteProjectRequest",
    "ProjectApiGetProjectRequest",
    "ProjectApiListProjectsRequest",
    "ProjectApiUpdateProjectRequest",
    "AccountV3ProjectAPI",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import DatabaseBackupStatus
from .types import DatabaseStatus
from .content import DATABASE_TRANSIENT_STATUSES
from .types import ListDatabaseBackupsRequestOrderBy
from .types import ListDatabasesRequestOrderBy
from .types import DatabaseBackup
from .types import Database
from .types import CreateDatabaseRequest
from .types import DeleteDatabaseRequest
from .types import ExportDatabaseBackupRequest
from .types import GetDatabaseBackupRequest
from .types import GetDatabaseRequest
from .types import ListDatabaseBackupsRequest
from .types import ListDatabaseBackupsResponse
from .types import ListDatabasesRequest
from .types import ListDatabasesResponse
from .types import RestoreDatabaseFromBackupRequest
from .types import UpdateDatabaseRequest
from .api import ServerlessSqldbV1Alpha1API

__all__ = [
    "DatabaseBackupStatus",
    "DatabaseStatus",
    "DATABASE_TRANSIENT_STATUSES",
    "ListDatabaseBackupsRequestOrderBy",
    "ListDatabasesRequestOrderBy",
    "DatabaseBackup",
    "Database",
    "CreateDatabaseRequest",
    "DeleteDatabaseRequest",
    "ExportDatabaseBackupRequest",
    "GetDatabaseBackupRequest",
    "GetDatabaseRequest",
    "ListDatabaseBackupsRequest",
    "ListDatabaseBackupsResponse",
    "ListDatabasesRequest",
    "ListDatabasesResponse",
    "RestoreDatabaseFromBackupRequest",
    "UpdateDatabaseRequest",
    "ServerlessSqldbV1Alpha1API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import JobRunState
from .content import JOB_RUN_TRANSIENT_STATUSES
from .types import ListJobDefinitionsRequestOrderBy
from .types import ListJobRunsRequestOrderBy
from .types import CronSchedule
from .types import CreateJobDefinitionRequestCronScheduleConfig
from .types import JobDefinition
from .types import JobRun
from .types import Resource
from .types import UpdateJobDefinitionRequestCronScheduleConfig
from .types import CreateJobDefinitionRequest
from .types import DeleteJobDefinitionRequest
from .types import GetJobDefinitionRequest
from .types import GetJobRunRequest
from .types import ListJobDefinitionsRequest
from .types import ListJobDefinitionsResponse
from .types import ListJobRunsRequest
from .types import ListJobRunsResponse
from .types import ListJobsResourcesRequest
from .types import ListJobsResourcesResponse
from .types import StartJobDefinitionRequest
from .types import StartJobDefinitionResponse
from .types import StopJobRunRequest
from .types import UpdateJobDefinitionRequest
from .api import JobsV1Alpha1API

__all__ = [
    "JobRunState",
    "JOB_RUN_TRANSIENT_STATUSES",
    "ListJobDefinitionsRequestOrderBy",
    "ListJobRunsRequestOrderBy",
    "CronSchedule",
    "CreateJobDefinitionRequestCronScheduleConfig",
    "JobDefinition",
    "JobRun",
    "Resource",
    "UpdateJobDefinitionRequestCronScheduleConfig",
    "CreateJobDefinitionRequest",
    "DeleteJobDefinitionRequest",
    "GetJobDefinitionRequest",
    "GetJobRunRequest",
    "ListJobDefinitionsRequest",
    "ListJobDefinitionsResponse",
    "ListJobRunsRequest",
    "ListJobRunsResponse",
    "ListJobsResourcesRequest",
    "ListJobsResourcesResponse",
    "StartJobDefinitionRequest",
    "StartJobDefinitionResponse",
    "StopJobRunRequest",
    "UpdateJobDefinitionRequest",
    "JobsV1Alpha1API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import DataSourceOrigin
from .types import DataSourceType
from .types import GrafanaUserRole
from .types import ListDataSourcesRequestOrderBy
from .types import ListGrafanaUsersRequestOrderBy
from .types import ListManagedAlertsRequestOrderBy
from .types import ListPlansRequestOrderBy
from .types import ListTokensRequestOrderBy
from .types import PlanName
from .types import TokenScope
from .types import UsageUnit
from .types import ContactPointEmail
from .types import ContactPoint
from .types import DataSource
from .types import GrafanaProductDashboard
from .types import GrafanaUser
from .types import Alert
from .types import Plan
from .types import Token
from .types import Usage
from .types import AlertManager
from .types import GlobalApiCreateGrafanaUserRequest
from .types import GlobalApiDeleteGrafanaUserRequest
from .types import GlobalApiGetCurrentPlanRequest
from .types import GlobalApiGetGrafanaProductDashboardRequest
from .types import GlobalApiGetGrafanaRequest
from .types import GlobalApiListGrafanaProductDashboardsRequest
from .types import GlobalApiListGrafanaUsersRequest
from .types import GlobalApiListPlansRequest
from .types import GlobalApiResetGrafanaUserPasswordRequest
from .types import GlobalApiSelectPlanRequest
from .types import GlobalApiSyncGrafanaDataSourcesRequest
from .types import Grafana
from .types import ListContactPointsResponse
from .types import ListDataSourcesResponse
from .types import ListGrafanaProductDashboardsResponse
from .types import ListGrafanaUsersResponse
from .types import ListManagedAlertsResponse
from .types import ListPlansResponse
from .types import ListTokensResponse
from .types import RegionalApiCreateContactPointRequest
from .types import RegionalApiCreateDataSourceRequest
from .types import RegionalApiCreateTokenRequest
from .types import RegionalApiDeleteContactPointRequest
from .types import RegionalApiDeleteDataSourceRequest
from .types import RegionalApiDeleteTokenRequest
from .types import RegionalApiDisableAlertManagerRequest
from .types import RegionalApiDisableManagedAlertsRequest
from .types import RegionalApiEnableAlertManagerRequest
from .types import RegionalApiEnableManagedAlertsRequest
from .types import RegionalApiGetAlertManagerRequest
from .types import RegionalApiGetDataSourceRequest
from .types import RegionalApiGetTokenRequest
from .types import RegionalApiGetUsageOverviewRequest
from .types import RegionalApiListContactPointsRequest
from .types import RegionalApiListDataSourcesRequest
from .types import RegionalApiListManagedAlertsRequest
from .types import RegionalApiListTokensRequest
from .types import RegionalApiTriggerTestAlertRequest
from .types import RegionalApiUpdateDataSourceRequest
from .types import UsageOverview
from .api import CockpitV1GlobalAPI
from .api import CockpitV1RegionalAPI

__all__ = [
    "DataSourceOrigin",
    "DataSourceType",
    "GrafanaUserRole",
    "ListDataSourcesRequestOrderBy",
    "ListGrafanaUsersRequestOrderBy",
    "ListManagedAlertsRequestOrderBy",
    "ListPlansRequestOrderBy",
    "ListTokensRequestOrderBy",
    "PlanName",
    "TokenScope",
    "UsageUnit",
    "ContactPointEmail",
    "ContactPoint",
    "DataSource",
    "GrafanaProductDashboard",
    "GrafanaUser",
    "Alert",
    "Plan",
    "Token",
    "Usage",
    "AlertManager",
    "GlobalApiCreateGrafanaUserRequest",
    "GlobalApiDeleteGrafanaUserRequest",
    "GlobalApiGetCurrentPlanRequest",
    "GlobalApiGetGrafanaProductDashboardRequest",
    "GlobalApiGetGrafanaRequest",
    "GlobalApiListGrafanaProductDashboardsRequest",
    "GlobalApiListGrafanaUsersRequest",
    "GlobalApiListPlansRequest",
    "GlobalApiResetGrafanaUserPasswordRequest",
    "GlobalApiSelectPlanRequest",
    "GlobalApiSyncGrafanaDataSourcesRequest",
    "Grafana",
    "ListContactPointsResponse",
    "ListDataSourcesResponse",
    "ListGrafanaProductDashboardsResponse",
    "ListGrafanaUsersResponse",
    "ListManagedAlertsResponse",
    "ListPlansResponse",
    "ListTokensResponse",
    "RegionalApiCreateContactPointRequest",
    "RegionalApiCreateDataSourceRequest",
    "RegionalApiCreateTokenRequest",
    "RegionalApiDeleteContactPointRequest",
    "RegionalApiDeleteDataSourceRequest",
    "RegionalApiDeleteTokenRequest",
    "RegionalApiDisableAlertManagerRequest",
    "RegionalApiDisableManagedAlertsRequest",
    "RegionalApiEnableAlertManagerRequest",
    "RegionalApiEnableManagedAlertsRequest",
    "RegionalApiGetAlertManagerRequest",
    "RegionalApiGetDataSourceRequest",
    "RegionalApiGetTokenRequest",
    "RegionalApiGetUsageOverviewRequest",
    "RegionalApiListContactPointsRequest",
    "RegionalApiListDataSourcesRequest",
    "RegionalApiListManagedAlertsRequest",
    "RegionalApiListTokensRequest",
    "RegionalApiTriggerTestAlertRequest",
    "RegionalApiUpdateDataSourceRequest",
    "UsageOverview",
    "CockpitV1GlobalAPI",
    "CockpitV1RegionalAPI",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from typing import List

from .types import (
    DatabaseStatus,
)

DATABASE_TRANSIENT_STATUSES: List[DatabaseStatus] = [
    DatabaseStatus.CREATING,
    DatabaseStatus.DELETING,
    DatabaseStatus.RESTORING,
]
"""
Lists transient statutes of the enum :class:`DatabaseStatus <DatabaseStatus>`.
"""



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import CronStatus
from .content import CRON_TRANSIENT_STATUSES
from .types import DomainStatus
from .content import DOMAIN_TRANSIENT_STATUSES
from .types import FunctionHttpOption
from .types import FunctionPrivacy
from .types import FunctionRuntime
from .types import FunctionSandbox
from .types import FunctionStatus
from .content import FUNCTION_TRANSIENT_STATUSES
from .types import ListCronsRequestOrderBy
from .types import ListDomainsRequestOrderBy
from .types import ListFunctionsRequestOrderBy
from .types import ListNamespacesRequestOrderBy
from .types import ListTokensRequestOrderBy
from .types import ListTriggersRequestOrderBy
from .types import NamespaceStatus
from .content import NAMESPACE_TRANSIENT_STATUSES
from .types import RuntimeStatus
from .types import TokenStatus
from .content import TOKEN_TRANSIENT_STATUSES
from .types import TriggerInputType
from .types import TriggerStatus
from .content import TRIGGER_TRANSIENT_STATUSES
from .types import SecretHashedValue
from .types import TriggerMnqNatsClientConfig
from .types import TriggerMnqSqsClientConfig
from .types import TriggerSqsClientConfig
from .types import Secret
from .types import CreateTriggerRequestMnqNatsClientConfig
from .types import CreateTriggerRequestMnqSqsClientConfig
from .types import CreateTriggerRequestSqsClientConfig
from .types import Cron
from .types import Domain
from .types import Runtime
from .types import Function
from .types import Namespace
from .types import Token
from .types import Trigger
from .types import UpdateTriggerRequestSqsClientConfig
from .types import CreateCronRequest
from .types import CreateDomainRequest
from .types import CreateFunctionRequest
from .types import CreateNamespaceRequest
from .types import CreateTokenRequest
from .types import CreateTriggerRequest
from .types import DeleteCronRequest
from .types import DeleteDomainRequest
from .types import DeleteFunctionRequest
from .types import DeleteNamespaceRequest
from .types import DeleteTokenRequest
from .types import DeleteTriggerRequest
from .types import DeployFunctionRequest
from .types import DownloadURL
from .types import GetCronRequest
from .types import GetDomainRequest
from .types import GetFunctionDownloadURLRequest
from .types import GetFunctionRequest
from .types import GetFunctionUploadURLRequest
from .types import GetNamespaceRequest
from .types import GetTokenRequest
from .types import GetTriggerRequest
from .types import IssueJWTRequest
from .types import ListCronsRequest
from .types import ListCronsResponse
from .types import ListDomainsRequest
from .types import ListDomainsResponse
from .types import ListFunctionRuntimesRequest
from .types import ListFunctionRuntimesResponse
from .types import ListFunctionsRequest
from .types import ListFunctionsResponse
from .types import ListNamespacesRequest
from .types import ListNamespacesResponse
from .types import ListTokensRequest
from .types import ListTokensResponse
from .types import ListTriggersRequest
from .types import ListTriggersResponse
from .types import UpdateCronRequest
from .types import UpdateFunctionRequest
from .types import UpdateNamespaceRequest
from .types import UpdateTriggerRequest
from .types import UploadURL
from .api import FunctionV1Beta1API

__all__ = [
    "CronStatus",
    "CRON_TRANSIENT_STATUSES",
    "DomainStatus",
    "DOMAIN_TRANSIENT_STATUSES",
    "FunctionHttpOption",
    "FunctionPrivacy",
    "FunctionRuntime",
    "FunctionSandbox",
    "FunctionStatus",
    "FUNCTION_TRANSIENT_STATUSES",
    "ListCronsRequestOrderBy",
    "ListDomainsRequestOrderBy",
    "ListFunctionsRequestOrderBy",
    "ListNamespacesRequestOrderBy",
    "ListTokensRequestOrderBy",
    "ListTriggersRequestOrderBy",
    "NamespaceStatus",
    "NAMESPACE_TRANSIENT_STATUSES",
    "RuntimeStatus",
    "TokenStatus",
    "TOKEN_TRANSIENT_STATUSES",
    "TriggerInputType",
    "TriggerStatus",
    "TRIGGER_TRANSIENT_STATUSES",
    "SecretHashedValue",
    "TriggerMnqNatsClientConfig",
    "TriggerMnqSqsClientConfig",
    "TriggerSqsClientConfig",
    "Secret",
    "CreateTriggerRequestMnqNatsClientConfig",
    "CreateTriggerRequestMnqSqsClientConfig",
    "CreateTriggerRequestSqsClientConfig",
    "Cron",
    "Domain",
    "Runtime",
    "Function",
    "Namespace",
    "Token",
    "Trigger",
    "UpdateTriggerRequestSqsClientConfig",
    "CreateCronRequest",
    "CreateDomainRequest",
    "CreateFunctionRequest",
    "CreateNamespaceRequest",
    "CreateTokenRequest",
    "CreateTriggerRequest",
    "DeleteCronRequest",
    "DeleteDomainRequest",
    "DeleteFunctionRequest",
    "DeleteNamespaceRequest",
    "DeleteTokenRequest",
    "DeleteTriggerRequest",
    "DeployFunctionRequest",
    "DownloadURL",
    "GetCronRequest",
    "GetDomainRequest",
    "GetFunctionDownloadURLRequest",
    "GetFunctionRequest",
    "GetFunctionUploadURLRequest",
    "GetNamespaceRequest",
    "GetTokenRequest",
    "GetTriggerRequest",
    "IssueJWTRequest",
    "ListCronsRequest",
    "ListCronsResponse",
    "ListDomainsRequest",
    "ListDomainsResponse",
    "ListFunctionRuntimesRequest",
    "ListFunctionRuntimesResponse",
    "ListFunctionsRequest",
    "ListFunctionsResponse",
    "ListNamespacesRequest",
    "ListNamespacesResponse",
    "ListTokensRequest",
    "ListTokensResponse",
    "ListTriggersRequest",
    "ListTriggersResponse",
    "UpdateCronRequest",
    "UpdateFunctionRequest",
    "UpdateNamespaceRequest",
    "UpdateTriggerRequest",
    "UploadURL",
    "FunctionV1Beta1API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime
from enum import Enum
from typing import List, Optional

from scaleway_core.bridge import (
    Region,
    Zone,
)
from scaleway_core.utils import (
    StrEnumMeta,
)


class DNSStageType(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_TYPE = "unknown_type"
    AUTO = "auto"
    MANAGED = "managed"
    CUSTOM = "custom"

    def __str__(self) -> str:
        return str(self.value)


class LbOriginError(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN = "unknown"
    TIMEOUT = "timeout"
    CONNECTION_REFUSED = "connection_refused"
    TLS_ERROR = "tls_error"

    def __str__(self) -> str:
        return str(self.value)


class ListBackendStagesRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListCacheStagesRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListDNSStagesRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListPipelinesRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListPurgeRequestsRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListTLSStagesRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"

    def __str__(self) -> str:
        return str(self.value)


class PipelineErrorCode(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_CODE = "unknown_code"
    DNS_INVALID_FORMAT = "dns_invalid_format"
    DNS_INVALID_TLD = "dns_invalid_tld"
    DNS_FORBIDDEN_ROOT_DOMAIN = "dns_forbidden_root_domain"
    DNS_FORBIDDEN_SCW_CLOUD = "dns_forbidden_scw_cloud"
    DNS_DOMAIN_DONT_EXIST = "dns_domain_dont_exist"
    DNS_CNAME_DONT_EXIST = "dns_cname_dont_exist"
    DNS_CNAME_RESOLVE = "dns_cname_resolve"
    DNS_FQDN_ALREADY_EXISTS = "dns_fqdn_already_exists"
    DNS_FQDN_ALREADY_IN_USE = "dns_fqdn_already_in_use"
    TLS_CERT_DELETED = "tls_cert_deleted"
    TLS_CERT_DISABLED = "tls_cert_disabled"
    TLS_CERT_EXPIRED = "tls_cert_expired"
    TLS_CERT_INVALID_FORMAT = "tls_cert_invalid_format"
    TLS_CERT_MISSING = "tls_cert_missing"
    TLS_CHAIN_ORDER = "tls_chain_order"
    TLS_KEY_INVALID_FORMAT = "tls_key_invalid_format"
    TLS_KEY_MISSING = "tls_key_missing"
    TLS_KEY_TOO_MANY = "tls_key_too_many"
    TLS_MANAGED_DOMAIN_RATE_LIMIT = "tls_managed_domain_rate_limit"
    TLS_MANAGED_INTERNAL = "tls_managed_internal"
    TLS_PAIR_MISMATCH = "tls_pair_mismatch"
    TLS_ROOT_INCONSISTENT = "tls_root_inconsistent"
    TLS_ROOT_INCORRECT = "tls_root_incorrect"
    TLS_ROOT_MISSING = "tls_root_missing"
    TLS_SAN_MISMATCH = "tls_san_mismatch"
    TLS_SELF_SIGNED = "tls_self_signed"

    def __str__(self) -> str:
        return str(self.value)


class PipelineErrorSeverity(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_SEVERITY = "unknown_severity"
    WARNING = "warning"
    CRITICAL = "critical"

    def __str__(self) -> str:
        return str(self.value)


class PipelineErrorStage(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_STAGE = "unknown_stage"
    DNS = "dns"
    TLS = "tls"
    CACHE = "cache"
    BACKEND = "backend"

    def __str__(self) -> str:
        return str(self.value)


class PipelineErrorType(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_TYPE = "unknown_type"
    RUNTIME = "runtime"
    CONFIG = "config"

    def __str__(self) -> str:
        return str(self.value)


class PipelineStatus(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_STATUS = "unknown_status"
    READY = "ready"
    ERROR = "error"
    PENDING = "pending"
    WARNING = "warning"

    def __str__(self) -> str:
        return str(self.value)


class PurgeRequestStatus(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_STATUS = "unknown_status"
    DONE = "done"
    ERROR = "error"
    PENDING = "pending"

    def __str__(self) -> str:
        return str(self.value)


@dataclass
class ScalewayLb:
    id: str
    """
    ID of the Load Balancer.
    """

    zone: Zone
    """
    Zone of the Load Balancer.
    """

    frontend_id: str
    """
    ID of the frontend linked to the Load Balancer.
    """

    is_ssl: Optional[bool]
    """
    Defines whether the Load Balancer's frontend handles SSL connections.
    """

    domain_name: Optional[str]
    """
    Fully Qualified Domain Name (in the format subdomain.example.com) to use in HTTP requests sent towards your Load Balancer.
    """


@dataclass
class ScalewayLbBackendConfig:
    lbs: List[ScalewayLb]
    """
    Load Balancer information.
    """


@dataclass
class ScalewayS3BackendConfig:
    bucket_name: Optional[str]
    """
    Name of the Bucket.
    """

    bucket_region: Optional[str]
    """
    Region of the Bucket.
    """

    is_website: Optional[bool]
    """
    Defines whether the bucket website feature is enabled.
    """


@dataclass
class PipelineError:
    stage: PipelineErrorStage

    code: PipelineErrorCode

    severity: PipelineErrorSeverity

    message: str

    type_: PipelineErrorType


@dataclass
class TLSSecret:
    secret_id: str
    """
    ID of the Secret.
    """

    region: Region
    """
    Region of the Secret.
    """


@dataclass
class CheckPEMChainRequestSecretChain:
    secret_id: str

    secret_region: str


@dataclass
class BackendStage:
    id: str
    """
    ID of the backend stage.
    """

    project_id: str
    """
    Project ID of the backend stage.
    """

    pipeline_id: Optional[str]
    """
    Pipeline ID the backend stage belongs to.
    """

    created_at: Optional[datetime]
    """
    Date the backend stage was created.
    """

    updated_at: Optional[datetime]
    """
    Date the backend stage was last updated.
    """

    scaleway_s3: Optional[ScalewayS3BackendConfig]

    scaleway_lb: Optional[ScalewayLbBackendConfig]


@dataclass
class CacheStage:
    id: str
    """
    ID of the cache stage.
    """

    project_id: str
    """
    Project ID of the cache stage.
    """

    pipeline_id: Optional[str]
    """
    Pipeline ID the cache stage belongs to.
    """

    fallback_ttl: Optional[str]
    """
    Time To Live (TTL) in seconds. Defines how long content is cached.
    """

    created_at: Optional[datetime]
    """
    Date the cache stage was created.
    """

    updated_at: Optional[datetime]
    """
    Date the cache stage was last updated.
    """

    backend_stage_id: Optional[str]


@dataclass
class DNSStage:
    id: str
    """
    ID of the DNS stage.
    """

    fqdns: List[str]
    """
    List of Fully Qualified Domain Names attached to the stage.
    """

    type_: DNSStageType
    """
    Type of the stage.
    """

    project_id: str
    """
    Project ID of the DNS stage.
    """

    pipeline_id: Optional[str]
    """
    Pipeline ID the DNS stage belongs to.
    """

    created_at: Optional[datetime]
    """
    Date the DNS stage was created.
    """

    updated_at: Optional[datetime]
    """
    Date the DNS stage was last updated.
    """

    tls_stage_id: Optional[str]

    cache_stage_id: Optional[str]

    backend_stage_id: Optional[str]


@dataclass
class Pipeline:
    id: str
    """
    ID of the pipeline.
    """

    name: str
    """
    Name of the pipeline.
    """

    description: str
    """
    Description of the pipeline.
    """

    status: PipelineStatus
    """
    Status of the pipeline.
    """

    errors: List[PipelineError]
    """
    Errors of the pipeline.
    """

    project_id: str
    """
    Project ID of the pipeline.
    """

    created_at: Optional[datetime]
    """
    Date the pipeline was created.
    """

    updated_at: Optional[datetime]
    """
    Date the pipeline was last updated.
    """

    dns_stage_id: Optional[str]


@dataclass
class PurgeRequest:
    id: str
    """
    ID of the purge request.
    """

    pipeline_id: str
    """
    Pipeline ID the purge request belongs to.
    """

    status: PurgeRequestStatus
    """
    Status of the purge request.
    """

    created_at: Optional[datetime]
    """
    Date the purge request was created.
    """

    updated_at: Optional[datetime]
    """
    Date the purge request was last updated.
    """

    assets: Optional[List[str]]

    all: Optional[bool]


@dataclass
class TLSStage:
    id: str
    """
    ID of the TLS stage.
    """

    secrets: List[TLSSecret]
    """
    Secret (from Scaleway Secret Manager) containing your custom certificate.
    """

    managed_certificate: bool
    """
    True when Scaleway generates and manages a Let's Encrypt certificate for the TLS stage/custom endpoint.
    """

    project_id: str
    """
    Project ID of the TLS stage.
    """

    pipeline_id: Optional[str]
    """
    Pipeline ID the TLS stage belongs to.
    """

    certificate_expires_at: Optional[datetime]
    """
    Expiration date of the certificate.
    """

    created_at: Optional[datetime]
    """
    Date the TLS stage was created.
    """

    updated_at: Optional[datetime]
    """
    Date the TLS stage was last updated.
    """

    cache_stage_id: Optional[str]

    backend_stage_id: Optional[str]


@dataclass
class TLSSecretsConfig:
    tls_secrets: List[TLSSecret]
    """
    Secret information (from Secret Manager).
    """


@dataclass
class CheckDomainRequest:
    fqdn: str

    cname: str

    project_id: Optional[str]


@dataclass
class CheckDomainResponse:
    is_valid: bool


@dataclass
class CheckLbOriginRequest:
    lb: Optional[ScalewayLb]


@dataclass
class CheckLbOriginResponse:
    is_valid: bool

    error_type: LbOriginError


@dataclass
class CheckPEMChainRequest:
    fqdn: str

    project_id: Optional[str]

    secret: Optional[CheckPEMChainRequestSecretChain]

    raw: Optional[str]


@dataclass
class CheckPEMChainResponse:
    is_valid: bool


@dataclass
class CreateBackendStageRequest:
    project_id: Optional[str]
    """
    Project ID in which the backend stage will be created.
    """

    scaleway_s3: Optional[ScalewayS3BackendConfig]

    scaleway_lb: Optional[ScalewayLbBackendConfig]


@dataclass
class CreateCacheStageRequest:
    project_id: Optional[str]
    """
    Project ID in which the cache stage will be created.
    """

    fallback_ttl: Optional[str]
    """
    Time To Live (TTL) in seconds. Defines how long content is cached.
    """

    backend_stage_id: Optional[str]


@dataclass
class CreateDNSStageRequest:
    project_id: Optional[str]
    """
    Project ID in which the DNS stage will be created.
    """

    fqdns: Optional[List[str]]
    """
    Fully Qualified Domain Name (in the format subdomain.example.com) to attach to the stage.
    """

    tls_stage_id: Optional[str]

    cache_stage_id: Optional[str]

    backend_stage_id: Optional[str]


@dataclass
class CreatePipelineRequest:
    name: str
    """
    Name of the pipeline.
    """

    description: str
    """
    Description of the pipeline.
    """

    project_id: Optional[str]
    """
    Project ID in which the pipeline will be created.
    """

    dns_stage_id: Optional[str]


@dataclass
class CreatePurgeRequestRequest:
    pipeline_id: str
    """
    Pipeline ID in which the purge request will be created.
    """

    assets: Optional[List[str]]

    all: Optional[bool]


@dataclass
class CreateTLSStageRequest:
    project_id: Optional[str]
    """
    Project ID in which the TLS stage will be created.
    """

    secrets: Optional[List[TLSSecret]]
    """
    Secret (from Scaleway Secret Manager) containing your custom certificate.
    """

    managed_certificate: Optional[bool]
    """
    True when Scaleway generates and manages a Let's Encrypt certificate for the TLS stage/custom endpoint.
    """

    cache_stage_id: Optional[str]

    backend_stage_id: Optional[str]


@dataclass
class DeleteBackendStageRequest:
    backend_stage_id: str
    """
    ID of the backend stage to delete.
    """


@dataclass
class DeleteCacheStageRequest:
    cache_stage_id: str
    """
    ID of the cache stage to delete.
    """


@dataclass
class DeleteDNSStageRequest:
    dns_stage_id: str
    """
    ID of the DNS stage to delete.
    """


@dataclass
class DeletePipelineRequest:
    pipeline_id: str
    """
    ID of the pipeline to delete.
    """


@dataclass
class DeleteTLSStageRequest:
    tls_stage_id: str
    """
    ID of the TLS stage to delete.
    """


@dataclass
class GetBackendStageRequest:
    backend_stage_id: str
    """
    ID of the requested backend stage.
    """


@dataclass
class GetCacheStageRequest:
    cache_stage_id: str
    """
    ID of the requested cache stage.
    """


@dataclass
class GetDNSStageRequest:
    dns_stage_id: str
    """
    ID of the requested DNS stage.
    """


@dataclass
class GetPipelineRequest:
    pipeline_id: str
    """
    ID of the requested pipeline.
    """


@dataclass
class GetPurgeRequestRequest:
    purge_request_id: str
    """
    ID of the requested purge request.
    """


@dataclass
class GetTLSStageRequest:
    tls_stage_id: str
    """
    ID of the requested TLS stage.
    """


@dataclass
class ListBackendStagesRequest:
    order_by: Optional[ListBackendStagesRequestOrderBy]
    """
    Sort order of backend stages in the response.
    """

    page: Optional[int]
    """
    Page number to return, from the paginated results.
    """

    page_size: Optional[int]
    """
    Number of backend stages to return per page.
    """

    pipeline_id: Optional[str]
    """
    Pipeline ID to filter for, only backend stages from this pipeline will be returned.
    """

    project_id: Optional[str]
    """
    Project ID to filter for, only backend stages from this Project will be returned.
    """

    bucket_name: Optional[str]
    """
    Bucket name to filter for, only backend stages from this Bucket will be returned.
    """

    bucket_region: Optional[str]
    """
    Bucket region to filter for, only backend stages with buckets in this region will be returned.
    """

    lb_id: Optional[str]
    """
    Load Balancer ID to filter for, only backend stages with this Load Balancer will be returned.
    """


@dataclass
class ListBackendStagesResponse:
    stages: List[BackendStage]
    """
    Paginated list of backend stages.
    """

    total_count: int
    """
    Count of all backend stages matching the requested criteria.
    """


@dataclass
class ListCacheStagesRequest:
    order_by: Optional[ListCacheStagesRequestOrderBy]
    """
    Sort order of cache stages in the response.
    """

    page: Optional[int]
    """
    Page number to return, from the paginated results.
    """

    page_size: Optional[int]
    """
    Number of cache stages to return per page.
    """

    pipeline_id: Optional[str]
    """
    Pipeline ID to filter for, only cache stages from this pipeline will be returned.
    """

    project_id: Optional[str]
    """
    Project ID to filter for, only cache stages from this Project will be returned.
    """


@dataclass
class ListCacheStagesResponse:
    stages: List[CacheStage]
    """
    Paginated list of cache stages.
    """

    total_count: int
    """
    Count of all cache stages matching the requested criteria.
    """


@dataclass
class ListDNSStagesRequest:
    order_by: Optional[ListDNSStagesRequestOrderBy]
    """
    Sort order of DNS stages in the response.
    """

    page: Optional[int]
    """
    Page number to return, from the paginated results.
    """

    page_size: Optional[int]
    """
    Number of DNS stages to return per page.
    """

    pipeline_id: Optional[str]
    """
    Pipeline ID to filter for, only DNS stages from this pipeline will be returned.
    """

    project_id: Optional[str]
    """
    Project ID to filter for, only DNS stages from this Project will be returned.
    """

    fqdn: Optional[str]
    """
    Fully Qualified Domain Name to filter for (in the format subdomain.example.com), only DNS stages with this FQDN will be returned.
    """


@dataclass
class ListDNSStagesResponse:
    stages: List[DNSStage]
    """
    Paginated list of DNS stages.
    """

    total_count: int
    """
    Count of all DNS stages matching the requested criteria.
    """


@dataclass
class ListPipelinesRequest:
    order_by: Optional[ListPipelinesRequestOrderBy]
    """
    Sort order of pipelines in the response.
    """

    page: Optional[int]
    """
    Page number to return, from the paginated results.
    """

    page_size: Optional[int]
    """
    Number of pipelines to return per page.
    """

    name: Optional[str]
    """
    Pipeline name to filter for, only pipelines with this string within their name will be returned.
    """

    organization_id: Optional[str]
    """
    Organization ID to filter for, only pipelines from this Organization will be returned.
    """

    project_id: Optional[str]
    """
    Project ID to filter for, only pipelines from this Project will be returned.
    """

    has_backend_stage_lb: Optional[bool]
    """
    Filter on backend stage, only pipelines with a Load Balancer origin will be returned.
    """


@dataclass
class ListPipelinesResponse:
    pipelines: List[Pipeline]
    """
    Paginated list of pipelines.
    """

    total_count: int
    """
    Count of all pipelines matching the requested criteria.
    """


@dataclass
class ListPurgeRequestsRequest:
    order_by: Optional[ListPurgeRequestsRequestOrderBy]
    """
    Sort order of purge requests in the response.
    """

    page: Optional[int]
    """
    Page number to return, from the paginated results.
    """

    page_size: Optional[int]
    """
    Number of purge requests to return per page.
    """

    organization_id: Optional[str]
    """
    Organization ID to filter for, only purge requests from this Project will be returned.
    """

    project_id: Optional[str]
    """
    Project ID to filter for, only purge requests from this Project will be returned.
    """

    pipeline_id: Optional[str]
    """
    Pipeline ID to filter for, only purge requests from this pipeline will be returned.
    """


@dataclass
class ListPurgeRequestsResponse:
    purge_requests: List[PurgeRequest]
    """
    Paginated list of purge requests.
    """

    total_count: int
    """
    Count of all purge requests matching the requested criteria.
    """


@dataclass
class ListTLSStagesRequest:
    order_by: Optional[ListTLSStagesRequestOrderBy]
    """
    Sort order of TLS stages in the response.
    """

    page: Optional[int]
    """
    Page number to return, from the paginated results.
    """

    page_size: Optional[int]
    """
    Number of TLS stages to return per page.
    """

    pipeline_id: Optional[str]
    """
    Pipeline ID to filter for, only TLS stages from this pipeline will be returned.
    """

    project_id: Optional[str]
    """
    Project ID to filter for, only TLS stages from this Project will be returned.
    """

    secret_id: Optional[str]
    """
    Secret ID to filter for, only TLS stages with this Secret ID will be returned.
    """

    secret_region: Optional[str]
    """
    Secret region to filter for, only TLS stages with a Secret in this region will be returned.
    """


@dataclass
class ListTLSStagesResponse:
    stages: List[TLSStage]
    """
    Paginated list of TLS stages.
    """

    total_count: int
    """
    Count of all TLS stages matching the requested criteria.
    """


@dataclass
class UpdateBackendStageRequest:
    backend_stage_id: str
    """
    ID of the backend stage to update.
    """

    scaleway_s3: Optional[ScalewayS3BackendConfig]

    scaleway_lb: Optional[ScalewayLbBackendConfig]


@dataclass
class UpdateCacheStageRequest:
    cache_stage_id: str
    """
    ID of the cache stage to update.
    """

    fallback_ttl: Optional[str]
    """
    Time To Live (TTL) in seconds. Defines how long content is cached.
    """

    backend_stage_id: Optional[str]


@dataclass
class UpdateDNSStageRequest:
    dns_stage_id: str
    """
    ID of the DNS stage to update.
    """

    fqdns: Optional[List[str]]
    """
    Fully Qualified Domain Name (in the format subdomain.example.com) attached to the stage.
    """

    tls_stage_id: Optional[str]

    cache_stage_id: Optional[str]

    backend_stage_id: Optional[str]


@dataclass
class UpdatePipelineRequest:
    pipeline_id: str
    """
    ID of the pipeline to update.
    """

    name: Optional[str]
    """
    Name of the pipeline.
    """

    description: Optional[str]
    """
    Description of the pipeline.
    """

    dns_stage_id: Optional[str]


@dataclass
class UpdateTLSStageRequest:
    tls_stage_id: str
    """
    ID of the TLS stage to update.
    """

    tls_secrets_config: Optional[TLSSecretsConfig]
    """
    Secret (from Scaleway Secret-Manager) containing your custom certificate.
    """

    managed_certificate: Optional[bool]
    """
    True when Scaleway generates and manages a Let's Encrypt certificate for the TLS stage/custom endpoint.
    """

    cache_stage_id: Optional[str]

    backend_stage_id: Optional[str]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.

from typing import Any, Dict
from dateutil import parser

from scaleway_core.profile import ProfileDefaults
from .types import (
    OS,
    ServerTypeCPU,
    ServerTypeDisk,
    ServerTypeGPU,
    ServerTypeMemory,
    ServerTypeNetwork,
    ServerType,
    Server,
    ListOSResponse,
    ListServerTypesResponse,
    ListServersResponse,
    CreateServerRequest,
    ReinstallServerRequest,
    UpdateServerRequest,
)


def unmarshal_OS(data: Any) -> OS:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'OS' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("label", None)
    if field is not None:
        args["label"] = field

    field = data.get("image_url", None)
    if field is not None:
        args["image_url"] = field

    field = data.get("family", None)
    if field is not None:
        args["family"] = field

    field = data.get("is_beta", None)
    if field is not None:
        args["is_beta"] = field

    field = data.get("version", None)
    if field is not None:
        args["version"] = field

    field = data.get("xcode_version", None)
    if field is not None:
        args["xcode_version"] = field

    field = data.get("compatible_server_types", None)
    if field is not None:
        args["compatible_server_types"] = field

    return OS(**args)


def unmarshal_ServerTypeCPU(data: Any) -> ServerTypeCPU:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ServerTypeCPU' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("core_count", None)
    if field is not None:
        args["core_count"] = field

    field = data.get("frequency", None)
    if field is not None:
        args["frequency"] = field

    return ServerTypeCPU(**args)


def unmarshal_ServerTypeDisk(data: Any) -> ServerTypeDisk:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ServerTypeDisk' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("capacity", None)
    if field is not None:
        args["capacity"] = field

    field = data.get("type", None)
    if field is not None:
        args["type_"] = field

    return ServerTypeDisk(**args)


def unmarshal_ServerTypeGPU(data: Any) -> ServerTypeGPU:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ServerTypeGPU' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("count", None)
    if field is not None:
        args["count"] = field

    return ServerTypeGPU(**args)


def unmarshal_ServerTypeMemory(data: Any) -> ServerTypeMemory:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ServerTypeMemory' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("capacity", None)
    if field is not None:
        args["capacity"] = field

    field = data.get("type", None)
    if field is not None:
        args["type_"] = field

    return ServerTypeMemory(**args)


def unmarshal_ServerTypeNetwork(data: Any) -> ServerTypeNetwork:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ServerTypeNetwork' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("public_bandwidth_bps", None)
    if field is not None:
        args["public_bandwidth_bps"] = field

    return ServerTypeNetwork(**args)


def unmarshal_ServerType(data: Any) -> ServerType:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ServerType' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("stock", None)
    if field is not None:
        args["stock"] = field

    field = data.get("cpu", None)
    if field is not None:
        args["cpu"] = unmarshal_ServerTypeCPU(field)
    else:
        args["cpu"] = None

    field = data.get("disk", None)
    if field is not None:
        args["disk"] = unmarshal_ServerTypeDisk(field)
    else:
        args["disk"] = None

    field = data.get("memory", None)
    if field is not None:
        args["memory"] = unmarshal_ServerTypeMemory(field)
    else:
        args["memory"] = None

    field = data.get("minimum_lease_duration", None)
    if field is not None:
        args["minimum_lease_duration"] = field
    else:
        args["minimum_lease_duration"] = None

    field = data.get("gpu", None)
    if field is not None:
        args["gpu"] = unmarshal_ServerTypeGPU(field)
    else:
        args["gpu"] = None

    field = data.get("network", None)
    if field is not None:
        args["network"] = unmarshal_ServerTypeNetwork(field)
    else:
        args["network"] = None

    field = data.get("default_os", None)
    if field is not None:
        args["default_os"] = unmarshal_OS(field)
    else:
        args["default_os"] = None

    return ServerType(**args)


def unmarshal_Server(data: Any) -> Server:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'Server' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("id", None)
    if field is not None:
        args["id"] = field

    field = data.get("type", None)
    if field is not None:
        args["type_"] = field

    field = data.get("name", None)
    if field is not None:
        args["name"] = field

    field = data.get("project_id", None)
    if field is not None:
        args["project_id"] = field

    field = data.get("organization_id", None)
    if field is not None:
        args["organization_id"] = field

    field = data.get("ip", None)
    if field is not None:
        args["ip"] = field

    field = data.get("vnc_url", None)
    if field is not None:
        args["vnc_url"] = field

    field = data.get("ssh_username", None)
    if field is not None:
        args["ssh_username"] = field

    field = data.get("sudo_password", None)
    if field is not None:
        args["sudo_password"] = field

    field = data.get("status", None)
    if field is not None:
        args["status"] = field

    field = data.get("zone", None)
    if field is not None:
        args["zone"] = field

    field = data.get("os", None)
    if field is not None:
        args["os"] = unmarshal_OS(field)
    else:
        args["os"] = None

    field = data.get("created_at", None)
    if field is not None:
        args["created_at"] = parser.isoparse(field) if isinstance(field, str) else field
    else:
        args["created_at"] = None

    field = data.get("updated_at", None)
    if field is not None:
        args["updated_at"] = parser.isoparse(field) if isinstance(field, str) else field
    else:
        args["updated_at"] = None

    field = data.get("deletable_at", None)
    if field is not None:
        args["deletable_at"] = (
            parser.isoparse(field) if isinstance(field, str) else field
        )
    else:
        args["deletable_at"] = None

    return Server(**args)


def unmarshal_ListOSResponse(data: Any) -> ListOSResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListOSResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    field = data.get("os", None)
    if field is not None:
        args["os"] = [unmarshal_OS(v) for v in field] if field is not None else None

    return ListOSResponse(**args)


def unmarshal_ListServerTypesResponse(data: Any) -> ListServerTypesResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListServerTypesResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("server_types", None)
    if field is not None:
        args["server_types"] = (
            [unmarshal_ServerType(v) for v in field] if field is not None else None
        )

    return ListServerTypesResponse(**args)


def unmarshal_ListServersResponse(data: Any) -> ListServersResponse:
    if not isinstance(data, dict):
        raise TypeError(
            "Unmarshalling the type 'ListServersResponse' failed as data isn't a dictionary."
        )

    args: Dict[str, Any] = {}

    field = data.get("total_count", None)
    if field is not None:
        args["total_count"] = field

    field = data.get("servers", None)
    if field is not None:
        args["servers"] = (
            [unmarshal_Server(v) for v in field] if field is not None else None
        )

    return ListServersResponse(**args)


def marshal_CreateServerRequest(
    request: CreateServerRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.type_ is not None:
        output["type"] = request.type_

    if request.name is not None:
        output["name"] = request.name

    if request.project_id is not None:
        output["project_id"] = request.project_id or defaults.default_project_id

    if request.os_id is not None:
        output["os_id"] = request.os_id

    return output


def marshal_ReinstallServerRequest(
    request: ReinstallServerRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.os_id is not None:
        output["os_id"] = request.os_id

    return output


def marshal_UpdateServerRequest(
    request: UpdateServerRequest,
    defaults: ProfileDefaults,
) -> Dict[str, Any]:
    output: Dict[str, Any] = {}

    if request.name is not None:
        output["name"] = request.name

    return output



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime
from enum import Enum
from typing import List, Optional

from scaleway_core.bridge import (
    TimeSeries,
)
from scaleway_core.utils import (
    StrEnumMeta,
)


class CockpitStatus(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_STATUS = "unknown_status"
    CREATING = "creating"
    READY = "ready"
    DELETING = "deleting"
    UPDATING = "updating"
    ERROR = "error"

    def __str__(self) -> str:
        return str(self.value)


class DatasourceType(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_DATASOURCE_TYPE = "unknown_datasource_type"
    METRICS = "metrics"
    LOGS = "logs"
    TRACES = "traces"
    ALERTS = "alerts"

    def __str__(self) -> str:
        return str(self.value)


class GrafanaUserRole(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_ROLE = "unknown_role"
    EDITOR = "editor"
    VIEWER = "viewer"

    def __str__(self) -> str:
        return str(self.value)


class ListDatasourcesRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListGrafanaUsersRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    LOGIN_ASC = "login_asc"
    LOGIN_DESC = "login_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListPlansRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


class ListTokensRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_ASC = "created_at_asc"
    CREATED_AT_DESC = "created_at_desc"
    NAME_ASC = "name_asc"
    NAME_DESC = "name_desc"

    def __str__(self) -> str:
        return str(self.value)


class PlanName(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_NAME = "unknown_name"
    FREE = "free"
    PREMIUM = "premium"
    CUSTOM = "custom"

    def __str__(self) -> str:
        return str(self.value)


@dataclass
class ContactPointEmail:
    to: str


@dataclass
class TokenScopes:
    query_metrics: bool
    """
    Permission to fetch metrics.
    """

    write_metrics: bool
    """
    Permission to write metrics.
    """

    setup_metrics_rules: bool
    """
    Permission to setup metrics rules.
    """

    query_logs: bool
    """
    Permission to fetch logs.
    """

    write_logs: bool
    """
    Permission to write logs.
    """

    setup_logs_rules: bool
    """
    Permission to set up logs rules.
    """

    setup_alerts: bool
    """
    Permission to set up alerts.
    """

    query_traces: bool
    """
    Permission to fetch traces.
    """

    write_traces: bool
    """
    Permission to write traces.
    """


@dataclass
class CockpitEndpoints:
    metrics_url: str
    """
    URL for metrics.
    """

    logs_url: str
    """
    URL for logs.
    """

    traces_url: str
    """
    URL for traces.
    """

    alertmanager_url: str
    """
    URL for the alert manager.
    """

    grafana_url: str
    """
    URL for the Grafana dashboard.
    """


@dataclass
class Plan:
    """
    Pricing plan.
    """

    id: str
    """
    ID of a given pricing plan.
    """

    name: PlanName
    """
    Name of a given pricing plan.
    """

    sample_ingestion_price: int
    """
    Ingestion price in cents for 1 million samples.
    """

    logs_ingestion_price: int
    """
    Ingestion price in cents for 1 GB of logs.
    """

    traces_ingestion_price: int
    """
    Ingestion price in cents for 1 GB of traces.
    """

    retention_price: int
    """
    Retention price in euros per month.
    """

    retention_metrics_interval: Optional[str]
    """
    Interval of time during which Scaleway's Cockpit keeps your metrics.
    """

    retention_logs_interval: Optional[str]
    """
    Interval of time during which Scaleway's Cockpit keeps your logs.
    """

    retention_traces_interval: Optional[str]
    """
    Interval of time during which Scaleway's Cockpit keeps your traces.
    """


@dataclass
class ContactPoint:
    """
    Contact point.
    """

    email: Optional[ContactPointEmail]


@dataclass
class Datasource:
    """
    Data source.
    """

    id: str
    """
    ID of the data source.
    """

    project_id: str
    """
    ID of the Project the Cockpit belongs to.
    """

    name: str
    """
    Data source name.
    """

    url: str
    """
    Data source URL.
    """

    type_: DatasourceType
    """
    Data source type.
    """

    is_managed_by_scaleway: bool
    """
    Specifies that the data source receives data from Scaleway products and is managed by Scaleway.
    """


@dataclass
class GrafanaProductDashboard:
    """
    Grafana dashboard.
    """

    dashboard_name: str
    """
    Name of the dashboard.
    """

    title: str
    """
    Title of the dashboard.
    """

    url: str
    """
    URL of the dashboard.
    """

    tags: List[str]
    """
    Tags of the dashboard.
    """

    variables: List[str]
    """
    Variables of the dashboard.
    """


@dataclass
class GrafanaUser:
    """
    Grafana user.
    """

    id: int
    """
    ID of the Grafana user.
    """

    login: str
    """
    Username of the Grafana user.
    """

    role: GrafanaUserRole
    """
    Role assigned to the Grafana user.
    """

    password: Optional[str]
    """
    The Grafana user's password.
    """


@dataclass
class Token:
    id: str
    """
    ID of the token.
    """

    project_id: str
    """
    ID of the Project.
    """

    name: str
    """
    Name of the token.
    """

    created_at: Optional[datetime]
    """
    Date and time of the token's creation.
    """

    updated_at: Optional[datetime]
    """
    Date and time of the token's last update.
    """

    scopes: Optional[TokenScopes]
    """
    Token's permissions.
    """

    secret_key: Optional[str]
    """
    Token's secret key.
    """


@dataclass
class ActivateCockpitRequest:
    project_id: Optional[str]
    """
    ID of the Project the Cockpit belongs to.
    """


@dataclass
class Cockpit:
    """
    Cockpit.
    """

    project_id: str
    """
    ID of the Project the Cockpit belongs to.
    """

    status: CockpitStatus
    """
    Status of the Cockpit.
    """

    managed_alerts_enabled: bool
    """
    Specifies whether managed alerts are enabled or disabled.
    """

    created_at: Optional[datetime]
    """
    Date and time of the Cockpit's creation.
    """

    updated_at: Optional[datetime]
    """
    Date and time of the Cockpit's last update.
    """

    endpoints: Optional[CockpitEndpoints]
    """
    Endpoints of the Cockpit.
    """

    plan: Optional[Plan]
    """
    Pricing plan information.
    """


@dataclass
class CockpitMetrics:
    """
    Metrics for a given Cockpit.
    """

    timeseries: List[TimeSeries]
    """
    Time series array.
    """


@dataclass
class CreateContactPointRequest:
    """
    Request to create a contact point.
    """

    project_id: Optional[str]
    """
    ID of the Project in which to create the contact point.
    """

    contact_point: Optional[ContactPoint]
    """
    Contact point to create.
    """


@dataclass
class CreateDatasourceRequest:
    """
    Request to create a data source.
    """

    name: str
    """
    Data source name.
    """

    is_default: bool
    """
    Specifies that the returned output is the default data source per type.
    """

    project_id: Optional[str]
    """
    ID of the Project the Cockpit belongs to.
    """

    type_: Optional[DatasourceType]
    """
    Data source type.
    """


@dataclass
class CreateGrafanaUserRequest:
    """
    Request to create a Grafana user.
    """

    login: str
    """
    Username of the Grafana user.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """

    role: Optional[GrafanaUserRole]
    """
    Role assigned to the Grafana user.
    """


@dataclass
class CreateTokenRequest:
    project_id: Optional[str]
    """
    ID of the Project.
    """

    name: Optional[str]
    """
    Name of the token.
    """

    scopes: Optional[TokenScopes]
    """
    Token's permissions.
    """


@dataclass
class DeactivateCockpitRequest:
    project_id: Optional[str]
    """
    ID of the Project the Cockpit belongs to.
    """


@dataclass
class DeleteContactPointRequest:
    """
    Request to delete a contact point.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """

    contact_point: Optional[ContactPoint]
    """
    Contact point to delete.
    """


@dataclass
class DeleteDatasourceRequest:
    """
    Request to delete a data source.
    """

    datasource_id: str
    """
    ID of the data source.
    """


@dataclass
class DeleteGrafanaUserRequest:
    """
    Request to delete a Grafana user.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """

    grafana_user_id: int
    """
    ID of the Grafana user.
    """


@dataclass
class DeleteTokenRequest:
    token_id: str
    """
    ID of the token.
    """


@dataclass
class DisableManagedAlertsRequest:
    """
    Request to disable the sending of managed alerts.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """


@dataclass
class EnableManagedAlertsRequest:
    """
    Request to enable the sending of managed alerts.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """


@dataclass
class GetCockpitMetricsRequest:
    """
    Request to get a given Cockpit's metrics.
    """

    project_id: Optional[str]
    """
    ID of the Project the Cockpit belongs to.
    """

    start_date: Optional[datetime]
    """
    Desired time range's start date for the metrics.
    """

    end_date: Optional[datetime]
    """
    Desired time range's end date for the metrics.
    """

    metric_name: Optional[str]
    """
    Name of the metric requested.
    """


@dataclass
class GetCockpitRequest:
    project_id: Optional[str]
    """
    ID of the Project the Cockpit belongs to.
    """


@dataclass
class GetGrafanaProductDashboardRequest:
    """
    Request to get a dashboard.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """

    dashboard_name: str
    """
    Name of the dashboard.
    """


@dataclass
class GetTokenRequest:
    token_id: str
    """
    ID of the token.
    """


@dataclass
class ListContactPointsRequest:
    """
    Request to list all contact points.
    """

    page: Optional[int]
    """
    Page number.
    """

    page_size: Optional[int]
    """
    Page size.
    """

    project_id: Optional[str]
    """
    ID of the Project from which to list the contact points.
    """


@dataclass
class ListContactPointsResponse:
    """
    Response returned when listing contact points.
    """

    total_count: int
    """
    Count of all contact points created.
    """

    contact_points: List[ContactPoint]
    """
    Array of contact points.
    """

    has_additional_receivers: bool
    """
    Specifies whether the contact point has other receivers than the default receiver.
    """

    has_additional_contact_points: bool
    """
    Specifies whether there are unmanaged contact points.
    """


@dataclass
class ListDatasourcesRequest:
    page: Optional[int]
    """
    Page number.
    """

    page_size: Optional[int]
    """
    Page size.
    """

    order_by: Optional[ListDatasourcesRequestOrderBy]
    """
    How the response is ordered.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """

    types: Optional[List[DatasourceType]]
    """
    Filter by datasource types.
    """

    is_managed_by_scaleway: Optional[bool]
    """
    Filter by managed datasources.
    """


@dataclass
class ListDatasourcesResponse:
    total_count: int
    """
    Count of all datasources corresponding to the request.
    """

    datasources: List[Datasource]
    """
    List of the datasources within the pagination.
    """


@dataclass
class ListGrafanaProductDashboardsRequest:
    """
    Request to get a list of dashboards.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """

    page: Optional[int]
    """
    Page number.
    """

    page_size: Optional[int]
    """
    Page size.
    """

    tags: Optional[List[str]]
    """
    Tags to filter the dashboards.
    """


@dataclass
class ListGrafanaProductDashboardsResponse:
    """
    Response returned when getting a list of dashboards.
    """

    total_count: int
    """
    Count of grafana dasboards.
    """

    dashboards: List[GrafanaProductDashboard]
    """
    Information on grafana dashboards.
    """


@dataclass
class ListGrafanaUsersRequest:
    """
    Request to list all Grafana users.
    """

    page: Optional[int]
    """
    Page number.
    """

    page_size: Optional[int]
    """
    Page size.
    """

    order_by: Optional[ListGrafanaUsersRequestOrderBy]

    project_id: Optional[str]
    """
    ID of the Project.
    """


@dataclass
class ListGrafanaUsersResponse:
    """
    Response returned when listing Grafana users.
    """

    total_count: int
    """
    Count of all Grafana users.
    """

    grafana_users: List[GrafanaUser]
    """
    Information on all Grafana users.
    """


@dataclass
class ListPlansRequest:
    """
    Request to list all pricing plans.
    """

    page: Optional[int]
    """
    Page number.
    """

    page_size: Optional[int]
    """
    Page size.
    """

    order_by: Optional[ListPlansRequestOrderBy]


@dataclass
class ListPlansResponse:
    """
    Response returned when listing all pricing plans.
    """

    total_count: int
    """
    Count of all pricing plans.
    """

    plans: List[Plan]
    """
    Information on plans.
    """


@dataclass
class ListTokensRequest:
    page: Optional[int]
    """
    Page number.
    """

    page_size: Optional[int]
    """
    Page size.
    """

    order_by: Optional[ListTokensRequestOrderBy]
    """
    How the response is ordered.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """


@dataclass
class ListTokensResponse:
    total_count: int
    """
    Count of all tokens created.
    """

    tokens: List[Token]
    """
    List of all tokens created.
    """


@dataclass
class ResetGrafanaUserPasswordRequest:
    """
    Request to reset a Grafana user's password.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """

    grafana_user_id: int
    """
    ID of the Grafana user.
    """


@dataclass
class SelectPlanRequest:
    """
    Request to select a specific pricing plan.
    """

    plan_id: str
    """
    ID of the pricing plan.
    """

    project_id: Optional[str]
    """
    ID of the Project.
    """


@dataclass
class SelectPlanResponse:
    """
    Response returned when selecting a pricing plan.
    """

    pass


@dataclass
class TriggerTestAlertRequest:
    project_id: Optional[str]
